from __future__ import annotations
from typing import TYPE_CHECKING

from datetime import date, datetime
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Message(CreativeWork):
    """A single message from a sender to one or more organizations or people.

    See: https://schema.org/Message
    Model depth: 3
    """

    type_: str = Field(default="Message", alias="@type", const=True)
    dateSent: Optional[
        Union[List[Union[datetime, "DateTime", str]], datetime, "DateTime", str]
    ] = Field(
        default=None,
        description="The date/time at which the message was sent.",
    )
    bccRecipient: Optional[
        Union[
            List[Union["Organization", "Person", "ContactPoint", str]],
            "Organization",
            "Person",
            "ContactPoint",
            str,
        ]
    ] = Field(
        default=None,
        description="A sub property of recipient. The recipient blind copied on a message.",
    )
    recipient: Optional[
        Union[
            List[Union["Organization", "Audience", "Person", "ContactPoint", str]],
            "Organization",
            "Audience",
            "Person",
            "ContactPoint",
            str,
        ]
    ] = Field(
        default=None,
        description="A sub property of participant. The participant who is at the receiving end of the action.",
    )
    dateRead: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The date/time at which the message has been read by the recipient if a single recipient exists.",
    )
    dateReceived: Optional[
        Union[List[Union[datetime, "DateTime", str]], datetime, "DateTime", str]
    ] = Field(
        default=None,
        description="The date/time the message was received if a single recipient exists.",
    )
    messageAttachment: Optional[
        Union[List[Union["CreativeWork", str]], "CreativeWork", str]
    ] = Field(
        default=None,
        description="A CreativeWork attached to the message.",
    )
    sender: Optional[
        Union[
            List[Union["Audience", "Person", "Organization", str]],
            "Audience",
            "Person",
            "Organization",
            str,
        ]
    ] = Field(
        default=None,
        description="A sub property of participant. The participant who is at the sending end of the action.",
    )
    toRecipient: Optional[
        Union[
            List[Union["ContactPoint", "Audience", "Person", "Organization", str]],
            "ContactPoint",
            "Audience",
            "Person",
            "Organization",
            str,
        ]
    ] = Field(
        default=None,
        description="A sub property of recipient. The recipient who was directly sent the message.",
    )
    ccRecipient: Optional[
        Union[
            List[Union["ContactPoint", "Person", "Organization", str]],
            "ContactPoint",
            "Person",
            "Organization",
            str,
        ]
    ] = Field(
        default=None,
        description="A sub property of recipient. The recipient copied on a message.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.ContactPoint import ContactPoint
    from pydantic2_schemaorg.Audience import Audience
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.CreativeWork import CreativeWork



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.InteractAction import InteractAction


class JoinAction(InteractAction):
    """An agent joins an event/group with participants/friends at a location. Related actions: * [[RegisterAction]]:
     Unlike RegisterAction, JoinAction refers to joining a group/team of people. * [[SubscribeAction]]: Unlike
     SubscribeAction, JoinAction does not imply that you'll be receiving updates. * [[FollowAction]]: Unlike
     FollowAction, JoinAction does not imply that you'll be polling for updates.

    See: https://schema.org/JoinAction
    Model depth: 4
    """

    type_: str = Field(default="JoinAction", alias="@type", const=True)
    event: Optional[Union[List[Union["Event", str]], "Event", str]] = Field(
        default=None,
        description="Upcoming or past event associated with this place, organization, or action.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Event import Event



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalIntangible import MedicalIntangible


class DDxElement(MedicalIntangible):
    """An alternative, closely-related condition typically considered later in the differential diagnosis process
     along with the signs that are used to distinguish it.

    See: https://schema.org/DDxElement
    Model depth: 4
    """

    type_: str = Field(default="DDxElement", alias="@type", const=True)
    diagnosis: Optional[
        Union[List[Union["MedicalCondition", str]], "MedicalCondition", str]
    ] = Field(
        default=None,
        description="One or more alternative conditions considered in the differential diagnosis process as output of a diagnosis process.",
    )
    distinguishingSign: Optional[
        Union[List[Union["MedicalSignOrSymptom", str]], "MedicalSignOrSymptom", str]
    ] = Field(
        default=None,
        description="One of a set of signs and symptoms that can be used to distinguish this diagnosis from others in the differential diagnosis.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MedicalCondition import MedicalCondition
    from pydantic2_schemaorg.MedicalSignOrSymptom import MedicalSignOrSymptom



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.PriceSpecification import PriceSpecification


class DeliveryChargeSpecification(PriceSpecification):
    """The price for the delivery of an offer using a particular delivery method.

    See: https://schema.org/DeliveryChargeSpecification
    Model depth: 5
    """

    type_: str = Field(default="DeliveryChargeSpecification", alias="@type", const=True)
    eligibleRegion: Optional[
        Union[
            List[Union[str, "Text", "Place", "GeoShape"]],
            str,
            "Text",
            "Place",
            "GeoShape",
        ]
    ] = Field(
        default=None,
        description="The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid. See also [[ineligibleRegion]].",
    )
    appliesToDeliveryMethod: Optional[
        Union[List[Union["DeliveryMethod", str]], "DeliveryMethod", str]
    ] = Field(
        default=None,
        description="The delivery method(s) to which the delivery charge or payment charge specification applies.",
    )
    areaServed: Optional[
        Union[
            List[Union[str, "Text", "Place", "GeoShape", "AdministrativeArea"]],
            str,
            "Text",
            "Place",
            "GeoShape",
            "AdministrativeArea",
        ]
    ] = Field(
        default=None,
        description="The geographic area where a service or offered item is provided.",
    )
    ineligibleRegion: Optional[
        Union[
            List[Union[str, "Text", "Place", "GeoShape"]],
            str,
            "Text",
            "Place",
            "GeoShape",
        ]
    ] = Field(
        default=None,
        description="The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed. See also [[eligibleRegion]].",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Place import Place
    from pydantic2_schemaorg.GeoShape import GeoShape
    from pydantic2_schemaorg.DeliveryMethod import DeliveryMethod
    from pydantic2_schemaorg.AdministrativeArea import AdministrativeArea



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.SportsActivityLocation import SportsActivityLocation


class SportsClub(SportsActivityLocation):
    """A sports club.

    See: https://schema.org/SportsClub
    Model depth: 5
    """

    type_: str = Field(default="SportsClub", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Trip import Trip


class BusTrip(Trip):
    """A trip on a commercial bus line.

    See: https://schema.org/BusTrip
    Model depth: 4
    """

    type_: str = Field(default="BusTrip", alias="@type", const=True)
    busNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The unique identifier for the bus.",
    )
    departureBusStop: Optional[
        Union[List[Union["BusStation", "BusStop", str]], "BusStation", "BusStop", str]
    ] = Field(
        default=None,
        description="The stop or station from which the bus departs.",
    )
    busName: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The name of the bus (e.g. Bolt Express).",
    )
    arrivalBusStop: Optional[
        Union[List[Union["BusStation", "BusStop", str]], "BusStation", "BusStop", str]
    ] = Field(
        default=None,
        description="The stop or station from which the bus arrives.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.BusStation import BusStation
    from pydantic2_schemaorg.BusStop import BusStop



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MerchantReturnEnumeration import MerchantReturnEnumeration


class MerchantReturnNotPermitted(MerchantReturnEnumeration):
    """Specifies that product returns are not permitted.

    See: https://schema.org/MerchantReturnNotPermitted
    Model depth: 5
    """

    type_: str = Field(default="MerchantReturnNotPermitted", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DataFeed import DataFeed


class CompleteDataFeed(DataFeed):
    """A [[CompleteDataFeed]] is a [[DataFeed]] whose standard representation includes content for every item
     currently in the feed. This is the equivalent of Atom's element as defined in Feed Paging and Archiving [RFC
     5005](https://tools.ietf.org/html/rfc5005), for example (and as defined for Atom), when using data from
     a feed that represents a collection of items that varies over time (e.g. \"Top Twenty Records\") there is no
     need to have newer entries mixed in alongside older, obsolete entries. By marking this feed as a CompleteDataFeed,
     old entries can be safely discarded when the feed is refreshed, since we can assume the feed has provided descriptions
     for all current items.

    See: https://schema.org/CompleteDataFeed
    Model depth: 5
    """

    type_: str = Field(default="CompleteDataFeed", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Event import Event


class DanceEvent(Event):
    """Event type: A social dance.

    See: https://schema.org/DanceEvent
    Model depth: 3
    """

    type_: str = Field(default="DanceEvent", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class StatusEnumeration(Enumeration):
    """Lists or enumerations dealing with status types.

    See: https://schema.org/StatusEnumeration
    Model depth: 4
    """

    type_: str = Field(default="StatusEnumeration", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Action import Action


class TransferAction(Action):
    """The act of transferring/moving (abstract or concrete) animate or inanimate objects from one place to another.

    See: https://schema.org/TransferAction
    Model depth: 3
    """

    type_: str = Field(default="TransferAction", alias="@type", const=True)
    toLocation: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="A sub property of location. The final location of the object or the agent after the action.",
    )
    fromLocation: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="A sub property of location. The original location of the object or the agent before the action.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Place import Place



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictInt, StrictFloat
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.PeopleAudience import PeopleAudience


class ParentAudience(PeopleAudience):
    """A set of characteristics describing parents, who can be interested in viewing some content.

    See: https://schema.org/ParentAudience
    Model depth: 5
    """

    type_: str = Field(default="ParentAudience", alias="@type", const=True)
    childMinAge: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="Minimal age of the child.",
    )
    childMaxAge: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="Maximal age of the child.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Number import Number



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.NewsArticle import NewsArticle


class BackgroundNewsArticle(NewsArticle):
    """A [[NewsArticle]] providing historical context, definition and detail on a specific topic (aka \"explainer\"
     or \"backgrounder\"). For example, an in-depth article or frequently-asked-questions ([FAQ](https://en.wikipedia.org/wiki/FAQ))
     document on topics such as Climate Change or the European Union. Other kinds of background material from a
     non-news setting are often described using [[Book]] or [[Article]], in particular [[ScholarlyArticle]].
     See also [[NewsArticle]] for related vocabulary from a learning/education perspective.

    See: https://schema.org/BackgroundNewsArticle
    Model depth: 5
    """

    type_: str = Field(default="BackgroundNewsArticle", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.USNonprofitType import USNonprofitType


class Nonprofit501k(USNonprofitType):
    """Nonprofit501k: Non-profit type referring to Child Care Organizations.

    See: https://schema.org/Nonprofit501k
    Model depth: 6
    """

    type_: str = Field(default="Nonprofit501k", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Trip import Trip


class TouristTrip(Trip):
    """A tourist trip. A created itinerary of visits to one or more places of interest ([[TouristAttraction]]/[[TouristDestination]])
     often linked by a similar theme, geographic area, or interest to a particular [[touristType]]. The [UNWTO](http://www2.unwto.org/)
     defines tourism trip as the Trip taken by visitors. (See examples below.)

    See: https://schema.org/TouristTrip
    Model depth: 4
    """

    type_: str = Field(default="TouristTrip", alias="@type", const=True)
    touristType: Optional[
        Union[List[Union[str, "Text", "Audience"]], str, "Text", "Audience"]
    ] = Field(
        default=None,
        description="Attraction suitable for type(s) of tourist. E.g. children, visitors from a particular country, etc.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Audience import Audience



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DrugPregnancyCategory import DrugPregnancyCategory


class FDAcategoryB(DrugPregnancyCategory):
    """A designation by the US FDA signifying that animal reproduction studies have failed to demonstrate a risk
     to the fetus and there are no adequate and well-controlled studies in pregnant women.

    See: https://schema.org/FDAcategoryB
    Model depth: 6
    """

    type_: str = Field(default="FDAcategoryB", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.OrganizeAction import OrganizeAction


class ApplyAction(OrganizeAction):
    """The act of registering to an organization/service without the guarantee to receive it. Related actions:
     * [[RegisterAction]]: Unlike RegisterAction, ApplyAction has no guarantees that the application will
     be accepted.

    See: https://schema.org/ApplyAction
    Model depth: 4
    """

    type_: str = Field(default="ApplyAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DoseSchedule import DoseSchedule


class MaximumDoseSchedule(DoseSchedule):
    """The maximum dosing schedule considered safe for a drug or supplement as recommended by an authority or by the
     drug/supplement's manufacturer. Capture the recommending authority in the recognizingAuthority property
     of MedicalEntity.

    See: https://schema.org/MaximumDoseSchedule
    Model depth: 5
    """

    type_: str = Field(default="MaximumDoseSchedule", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from datetime import datetime, time


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class InteractionCounter(StructuredValue):
    """A summary of how users have interacted with this CreativeWork. In most cases, authors will use a subtype to
     specify the specific type of interaction.

    See: https://schema.org/InteractionCounter
    Model depth: 4
    """

    type_: str = Field(default="InteractionCounter", alias="@type", const=True)
    userInteractionCount: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description="The number of interactions for the CreativeWork using the WebSite or SoftwareApplication.",
    )
    startTime: Optional[
        Union[
            List[Union[datetime, "DateTime", time, "Time", str]],
            datetime,
            "DateTime",
            time,
            "Time",
            str,
        ]
    ] = Field(
        default=None,
        description="The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to start. For actions that span a period of time, when the action was performed. E.g. John wrote a book from *January* to December. For media, including audio and video, it's the time offset of the start of a clip within a larger file. Note that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.",
    )
    endTime: Optional[
        Union[
            List[Union[datetime, "DateTime", time, "Time", str]],
            datetime,
            "DateTime",
            time,
            "Time",
            str,
        ]
    ] = Field(
        default=None,
        description="The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to end. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to *December*. For media, including audio and video, it's the time offset of the end of a clip within a larger file. Note that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.",
    )
    interactionService: Optional[
        Union[
            List[Union["WebSite", "SoftwareApplication", str]],
            "WebSite",
            "SoftwareApplication",
            str,
        ]
    ] = Field(
        default=None,
        description="The WebSite or SoftwareApplication where the interactions took place.",
    )
    location: Optional[
        Union[
            List[Union[str, "Text", "Place", "PostalAddress", "VirtualLocation"]],
            str,
            "Text",
            "Place",
            "PostalAddress",
            "VirtualLocation",
        ]
    ] = Field(
        default=None,
        description="The location of, for example, where an event is happening, where an organization is located, or where an action takes place.",
    )
    interactionType: Optional[Union[List[Union["Action", str]], "Action", str]] = Field(
        default=None,
        description="The Action representing the type of interaction. For up votes, +1s, etc. use [[LikeAction]]. For down votes use [[DislikeAction]]. Otherwise, use the most specific Action.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Integer import Integer
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Time import Time
    from pydantic2_schemaorg.WebSite import WebSite
    from pydantic2_schemaorg.SoftwareApplication import SoftwareApplication
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Place import Place
    from pydantic2_schemaorg.PostalAddress import PostalAddress
    from pydantic2_schemaorg.VirtualLocation import VirtualLocation
    from pydantic2_schemaorg.Action import Action



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalBusiness import MedicalBusiness
from pydantic2_schemaorg.MedicalOrganization import MedicalOrganization


class Pharmacy(MedicalBusiness, MedicalOrganization):
    """A pharmacy or drugstore.

    See: https://schema.org/Pharmacy
    Model depth: 4
    """

    type_: str = Field(default="Pharmacy", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class MemberProgram(Intangible):
    """A MemberProgram defines a loyalty (or membership) program that provides its members with certain benefits,
     for example better pricing, free shipping or returns, or the ability to earn loyalty points. Member programs
     may have multiple tiers, for example silver and gold members, each with different benefits.

    See: https://schema.org/MemberProgram
    Model depth: 3
    """

    type_: str = Field(default="MemberProgram", alias="@type", const=True)
    hasTiers: Optional[
        Union[List[Union["MemberProgramTier", str]], "MemberProgramTier", str]
    ] = Field(
        default=None,
        description="The tiers of a member program.",
    )
    hostingOrganization: Optional[
        Union[List[Union["Organization", str]], "Organization", str]
    ] = Field(
        default=None,
        description="The Organization (airline, travelers' club, retailer, etc.) the membership is made with or which offers the MemberProgram.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MemberProgramTier import MemberProgramTier
    from pydantic2_schemaorg.Organization import Organization



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class QualitativeValue(Enumeration):
    """A predefined value for a product characteristic, e.g. the power cord plug type 'US' or the garment sizes 'S',
     'M', 'L', and 'XL'.

    See: https://schema.org/QualitativeValue
    Model depth: 4
    """

    type_: str = Field(default="QualitativeValue", alias="@type", const=True)
    greater: Optional[
        Union[List[Union["QualitativeValue", str]], "QualitativeValue", str]
    ] = Field(
        default=None,
        description="This ordering relation for qualitative values indicates that the subject is greater than the object.",
    )
    valueReference: Optional[
        Union[
            List[
                Union[
                    str,
                    "Text",
                    "QualitativeValue",
                    "PropertyValue",
                    "Enumeration",
                    "QuantitativeValue",
                    "DefinedTerm",
                    "StructuredValue",
                    "MeasurementTypeEnumeration",
                ]
            ],
            str,
            "Text",
            "QualitativeValue",
            "PropertyValue",
            "Enumeration",
            "QuantitativeValue",
            "DefinedTerm",
            "StructuredValue",
            "MeasurementTypeEnumeration",
        ]
    ] = Field(
        default=None,
        description="A secondary value that provides additional information on the original value, e.g. a reference temperature or a type of measurement.",
    )
    greaterOrEqual: Optional[
        Union[List[Union["QualitativeValue", str]], "QualitativeValue", str]
    ] = Field(
        default=None,
        description="This ordering relation for qualitative values indicates that the subject is greater than or equal to the object.",
    )
    equal: Optional[
        Union[List[Union["QualitativeValue", str]], "QualitativeValue", str]
    ] = Field(
        default=None,
        description="This ordering relation for qualitative values indicates that the subject is equal to the object.",
    )
    nonEqual: Optional[
        Union[List[Union["QualitativeValue", str]], "QualitativeValue", str]
    ] = Field(
        default=None,
        description="This ordering relation for qualitative values indicates that the subject is not equal to the object.",
    )
    lesser: Optional[
        Union[List[Union["QualitativeValue", str]], "QualitativeValue", str]
    ] = Field(
        default=None,
        description="This ordering relation for qualitative values indicates that the subject is lesser than the object.",
    )
    lesserOrEqual: Optional[
        Union[List[Union["QualitativeValue", str]], "QualitativeValue", str]
    ] = Field(
        default=None,
        description="This ordering relation for qualitative values indicates that the subject is lesser than or equal to the object.",
    )
    additionalProperty: Optional[
        Union[List[Union["PropertyValue", str]], "PropertyValue", str]
    ] = Field(
        default=None,
        description="A property-value pair representing an additional characteristic of the entity, e.g. a product feature or another characteristic for which there is no matching property in schema.org. Note: Publishers should be aware that applications designed to use specific schema.org properties (e.g. https://schema.org/width, https://schema.org/color, https://schema.org/gtin13, ...) will typically expect such data to be provided using those properties, rather than using the generic property/value mechanism.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.PropertyValue import PropertyValue
    from pydantic2_schemaorg.Enumeration import Enumeration
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm
    from pydantic2_schemaorg.StructuredValue import StructuredValue
    from pydantic2_schemaorg.MeasurementTypeEnumeration import (
        MeasurementTypeEnumeration,
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.StatusEnumeration import StatusEnumeration


class LegalForceStatus(StatusEnumeration):
    """A list of possible statuses for the legal force of a legislation.

    See: https://schema.org/LegalForceStatus
    Model depth: 5
    """

    type_: str = Field(default="LegalForceStatus", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ContactPointOption import ContactPointOption


class TollFree(ContactPointOption):
    """The associated telephone number is toll free.

    See: https://schema.org/TollFree
    Model depth: 5
    """

    type_: str = Field(default="TollFree", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl, StrictInt, StrictFloat
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.PriceSpecification import PriceSpecification


class UnitPriceSpecification(PriceSpecification):
    """The price asked for a given offer by the respective organization or person.

    See: https://schema.org/UnitPriceSpecification
    Model depth: 5
    """

    type_: str = Field(default="UnitPriceSpecification", alias="@type", const=True)
    unitCode: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL. Other codes than the UN/CEFACT Common Code may be used with a prefix followed by a colon.",
    )
    billingStart: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="Specifies after how much time this price (or price component) becomes valid and billing starts. Can be used, for example, to model a price increase after the first year of a subscription. The unit of measurement is specified by the unitCode property.",
    )
    referenceQuantity: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The reference quantity for which a certain price applies, e.g. 1 EUR per 4 kWh of electricity. This property is a replacement for unitOfMeasurement for the advanced cases where the price does not relate to a standard unit.",
    )
    billingIncrement: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="This property specifies the minimal quantity and rounding increment that will be the basis for the billing. The unit of measurement is specified by the unitCode property.",
    )
    billingDuration: Optional[
        Union[
            List[
                Union[
                    StrictInt,
                    StrictFloat,
                    "Number",
                    "Duration",
                    "QuantitativeValue",
                    str,
                ]
            ],
            StrictInt,
            StrictFloat,
            "Number",
            "Duration",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="Specifies for how long this price (or price component) will be billed. Can be used, for example, to model the contractual duration of a subscription or payment plan. Type can be either a Duration or a Number (in which case the unit of measurement, for example month, is specified by the unitCode property).",
    )
    priceType: Optional[
        Union[
            List[Union[str, "Text", "PriceTypeEnumeration"]],
            str,
            "Text",
            "PriceTypeEnumeration",
        ]
    ] = Field(
        default=None,
        description="Defines the type of a price specified for an offered product, for example a list price, a (temporary) sale price or a manufacturer suggested retail price. If multiple prices are specified for an offer the [[priceType]] property can be used to identify the type of each such specified price. The value of priceType can be specified as a value from enumeration PriceTypeEnumeration or as a free form text string for price types that are not already predefined in PriceTypeEnumeration.",
    )
    unitText: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A string or text indicating the unit of measurement. Useful if you cannot provide a standard unit code for <a href='unitCode'>unitCode</a>.",
    )
    priceComponentType: Optional[
        Union[
            List[Union["PriceComponentTypeEnumeration", str]],
            "PriceComponentTypeEnumeration",
            str,
        ]
    ] = Field(
        default=None,
        description="Identifies a price component (for example, a line item on an invoice), part of the total price for an offer.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.Duration import Duration
    from pydantic2_schemaorg.PriceTypeEnumeration import PriceTypeEnumeration
    from pydantic2_schemaorg.PriceComponentTypeEnumeration import (
        PriceComponentTypeEnumeration,
    )



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictBool, StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class PropertyValueSpecification(Intangible):
    """A Property value specification.

    See: https://schema.org/PropertyValueSpecification
    Model depth: 3
    """

    type_: str = Field(default="PropertyValueSpecification", alias="@type", const=True)
    defaultValue: Optional[
        Union[List[Union[str, "Text", "Thing"]], str, "Text", "Thing"]
    ] = Field(
        default=None,
        description="The default value of the input. For properties that expect a literal, the default is a literal value, for properties that expect an object, it's an ID reference to one of the current values.",
    )
    valueName: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Indicates the name of the PropertyValueSpecification to be used in URL templates and form encoding in a manner analogous to HTML's input@name.",
    )
    valueMinLength: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="Specifies the minimum allowed range for number of characters in a literal value.",
    )
    maxValue: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The upper value of some characteristic or property.",
    )
    minValue: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The lower value of some characteristic or property.",
    )
    valuePattern: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Specifies a regular expression for testing literal values according to the HTML spec.",
    )
    valueMaxLength: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="Specifies the allowed range for number of characters in a literal value.",
    )
    readonlyValue: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description='Whether or not a property is mutable. Default is false. Specifying this for a property that also has a value makes it act similar to a "hidden" input in an HTML form.',
    )
    valueRequired: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="Whether the property must be filled in to complete the action. Default is false.",
    )
    multipleValues: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="Whether multiple values are allowed for the property. Default is false.",
    )
    stepValue: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The stepValue attribute indicates the granularity that is expected (and required) of the value in a PropertyValueSpecification.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Thing import Thing
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.Boolean import Boolean



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DriveWheelConfigurationValue import (
    DriveWheelConfigurationValue,
)


class FourWheelDriveConfiguration(DriveWheelConfigurationValue):
    """Four-wheel drive is a transmission layout where the engine primarily drives two wheels with a part-time four-wheel
     drive capability.

    See: https://schema.org/FourWheelDriveConfiguration
    Model depth: 6
    """

    type_: str = Field(default="FourWheelDriveConfiguration", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ConsumeAction import ConsumeAction


class ReadAction(ConsumeAction):
    """The act of consuming written content.

    See: https://schema.org/ReadAction
    Model depth: 4
    """

    type_: str = Field(default="ReadAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.LegalForceStatus import LegalForceStatus


class NotInForce(LegalForceStatus):
    """Indicates that a legislation is currently not in force.

    See: https://schema.org/NotInForce
    Model depth: 6
    """

    type_: str = Field(default="NotInForce", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty
from pydantic2_schemaorg.MedicalBusiness import MedicalBusiness


class Midwifery(MedicalSpecialty, MedicalBusiness):
    """A nurse-like health profession that deals with pregnancy, childbirth, and the postpartum period (including
     care of the newborn), besides sexual and reproductive health of women throughout their lives.

    See: https://schema.org/Midwifery
    Model depth: 5
    """

    type_: str = Field(default="Midwifery", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Rating import Rating


class AggregateRating(Rating):
    """The average rating based on multiple ratings or reviews.

    See: https://schema.org/AggregateRating
    Model depth: 4
    """

    type_: str = Field(default="AggregateRating", alias="@type", const=True)
    ratingCount: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description="The count of total number of ratings.",
    )
    reviewCount: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description="The count of total number of reviews.",
    )
    itemReviewed: Optional[Union[List[Union["Thing", str]], "Thing", str]] = Field(
        default=None,
        description="The item that is being reviewed/rated.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Integer import Integer
    from pydantic2_schemaorg.Thing import Thing



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictBool
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class HealthPlanNetwork(Intangible):
    """A US-style health insurance plan network.

    See: https://schema.org/HealthPlanNetwork
    Model depth: 3
    """

    type_: str = Field(default="HealthPlanNetwork", alias="@type", const=True)
    healthPlanCostSharing: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="The costs to the patient for services under this network or formulary.",
    )
    healthPlanNetworkTier: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="The tier(s) for this network.",
        )
    )
    healthPlanNetworkId: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Name or unique ID of network. (Networks are often reused across different insurance plans.)",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class OrderItem(Intangible):
    """An order item is a line of an order. It includes the quantity and shipping details of a bought offer.

    See: https://schema.org/OrderItem
    Model depth: 3
    """

    type_: str = Field(default="OrderItem", alias="@type", const=True)
    orderItemStatus: Optional[
        Union[List[Union["OrderStatus", str]], "OrderStatus", str]
    ] = Field(
        default=None,
        description="The current status of the order item.",
    )
    orderDelivery: Optional[
        Union[List[Union["ParcelDelivery", str]], "ParcelDelivery", str]
    ] = Field(
        default=None,
        description="The delivery of the parcel related to this order or order item.",
    )
    orderItemNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The identifier of the order item.",
    )
    orderedItem: Optional[
        Union[
            List[Union["OrderItem", "Service", "Product", str]],
            "OrderItem",
            "Service",
            "Product",
            str,
        ]
    ] = Field(
        default=None,
        description="The item ordered.",
    )
    orderQuantity: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The number of the item ordered. If the property is not set, assume the quantity is one.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.OrderStatus import OrderStatus
    from pydantic2_schemaorg.ParcelDelivery import ParcelDelivery
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Service import Service
    from pydantic2_schemaorg.Product import Product
    from pydantic2_schemaorg.Number import Number



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.BodyMeasurementTypeEnumeration import (
    BodyMeasurementTypeEnumeration,
)


class BodyMeasurementHead(BodyMeasurementTypeEnumeration):
    """Maximum girth of head above the ears. Used, for example, to fit hats.

    See: https://schema.org/BodyMeasurementHead
    Model depth: 6
    """

    type_: str = Field(default="BodyMeasurementHead", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class PostalCodeRangeSpecification(StructuredValue):
    """Indicates a range of postal codes, usually defined as the set of valid codes between [[postalCodeBegin]]
     and [[postalCodeEnd]], inclusively.

    See: https://schema.org/PostalCodeRangeSpecification
    Model depth: 4
    """

    type_: str = Field(
        default="PostalCodeRangeSpecification", alias="@type", const=True
    )
    postalCodeBegin: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="First postal code in a range (included).",
    )
    postalCodeEnd: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Last postal code in the range (included). Needs to be after [[postalCodeBegin]].",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.WebPage import WebPage


class FAQPage(WebPage):
    """A [[FAQPage]] is a [[WebPage]] presenting one or more \"[Frequently asked questions](https://en.wikipedia.org/wiki/FAQ)\"
     (see also [[QAPage]]).

    See: https://schema.org/FAQPage
    Model depth: 4
    """

    type_: str = Field(default="FAQPage", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalIntangible import MedicalIntangible


class DoseSchedule(MedicalIntangible):
    """A specific dosing schedule for a drug or supplement.

    See: https://schema.org/DoseSchedule
    Model depth: 4
    """

    type_: str = Field(default="DoseSchedule", alias="@type", const=True)
    doseUnit: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The unit of the dose, e.g. 'mg'.",
    )
    frequency: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="How often the dose is taken, e.g. 'daily'.",
    )
    doseValue: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "QualitativeValue", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "QualitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The value of the dose, e.g. 500.",
    )
    targetPopulation: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Characteristics of the population for which this is intended, or which typically uses it, e.g. 'adults'.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.QualitativeValue import QualitativeValue



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.QualitativeValue import QualitativeValue


class SizeSpecification(QualitativeValue):
    """Size related properties of a product, typically a size code ([[name]]) and optionally a [[sizeSystem]],
     [[sizeGroup]], and product measurements ([[hasMeasurement]]). In addition, the intended audience can
     be defined through [[suggestedAge]], [[suggestedGender]], and suggested body measurements ([[suggestedMeasurement]]).

    See: https://schema.org/SizeSpecification
    Model depth: 5
    """

    type_: str = Field(default="SizeSpecification", alias="@type", const=True)
    sizeGroup: Optional[
        Union[
            List[Union[str, "Text", "SizeGroupEnumeration"]],
            str,
            "Text",
            "SizeGroupEnumeration",
        ]
    ] = Field(
        default=None,
        description='The size group (also known as "size type") for a product\'s size. Size groups are common in the fashion industry to define size segments and suggested audiences for wearable products. Multiple values can be combined, for example "men\'s big and tall", "petite maternity" or "regular".',
    )
    sizeSystem: Optional[
        Union[
            List[Union[str, "Text", "SizeSystemEnumeration"]],
            str,
            "Text",
            "SizeSystemEnumeration",
        ]
    ] = Field(
        default=None,
        description='The size system used to identify a product\'s size. Typically either a standard (for example, "GS1" or "ISO-EN13402"), country code (for example "US" or "JP"), or a measuring system (for example "Metric" or "Imperial").',
    )
    hasMeasurement: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="A measurement of an item, For example, the inseam of pants, the wheel size of a bicycle, the gauge of a screw, or the carbon footprint measured for certification by an authority. Usually an exact measurement, but can also be a range of measurements for adjustable products, for example belts and ski bindings.",
    )
    suggestedGender: Optional[
        Union[List[Union[str, "Text", "GenderType"]], str, "Text", "GenderType"]
    ] = Field(
        default=None,
        description='The suggested gender of the intended person or audience, for example "male", "female", or "unisex".',
    )
    suggestedAge: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The age or age range for the intended audience or person, for example 3-12 months for infants, 1-5 years for toddlers.",
    )
    suggestedMeasurement: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="A suggested range of body measurements for the intended audience or person, for example inseam between 32 and 34 inches or height between 170 and 190 cm. Typically found on a size chart for wearable products.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.SizeGroupEnumeration import SizeGroupEnumeration
    from pydantic2_schemaorg.SizeSystemEnumeration import SizeSystemEnumeration
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.GenderType import GenderType



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.SoftwareApplication import SoftwareApplication


class MobileApplication(SoftwareApplication):
    """A software application designed specifically to work well on a mobile device such as a telephone.

    See: https://schema.org/MobileApplication
    Model depth: 4
    """

    type_: str = Field(default="MobileApplication", alias="@type", const=True)
    carrierRequirements: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Specifies specific carrier(s) requirements for the application (e.g. an application may only work on a specific carrier network).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory


class Balance(PhysicalActivityCategory):
    """Physical activity that is engaged to help maintain posture and balance.

    See: https://schema.org/Balance
    Model depth: 5
    """

    type_: str = Field(default="Balance", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.PriceSpecification import PriceSpecification


class PaymentChargeSpecification(PriceSpecification):
    """The costs of settling the payment using a particular payment method.

    See: https://schema.org/PaymentChargeSpecification
    Model depth: 5
    """

    type_: str = Field(default="PaymentChargeSpecification", alias="@type", const=True)
    appliesToPaymentMethod: Optional[
        Union[List[Union["PaymentMethod", str]], "PaymentMethod", str]
    ] = Field(
        default=None,
        description="The payment method(s) to which the payment charge specification applies.",
    )
    appliesToDeliveryMethod: Optional[
        Union[List[Union["DeliveryMethod", str]], "DeliveryMethod", str]
    ] = Field(
        default=None,
        description="The delivery method(s) to which the delivery charge or payment charge specification applies.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.PaymentMethod import PaymentMethod
    from pydantic2_schemaorg.DeliveryMethod import DeliveryMethod



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from datetime import datetime


from pydantic.v1 import Field
from pydantic2_schemaorg.BlogPosting import BlogPosting


class LiveBlogPosting(BlogPosting):
    """A [[LiveBlogPosting]] is a [[BlogPosting]] intended to provide a rolling textual coverage of an ongoing
     event through continuous updates.

    See: https://schema.org/LiveBlogPosting
    Model depth: 6
    """

    type_: str = Field(default="LiveBlogPosting", alias="@type", const=True)
    liveBlogUpdate: Optional[
        Union[List[Union["BlogPosting", str]], "BlogPosting", str]
    ] = Field(
        default=None,
        description="An update to the LiveBlog.",
    )
    coverageStartTime: Optional[
        Union[List[Union[datetime, "DateTime", str]], datetime, "DateTime", str]
    ] = Field(
        default=None,
        description="The time when the live blog will begin covering the Event. Note that coverage may begin before the Event's start time. The LiveBlogPosting may also be created before coverage begins.",
    )
    coverageEndTime: Optional[
        Union[List[Union[datetime, "DateTime", str]], datetime, "DateTime", str]
    ] = Field(
        default=None,
        description="The time when the live blog will stop covering the Event. Note that coverage may continue after the Event concludes.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.BlogPosting import BlogPosting
    from pydantic2_schemaorg.DateTime import DateTime



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class DigitalPlatformEnumeration(Enumeration):
    """Enumerates some common technology platforms, for use with properties such as [[actionPlatform]]. It is
     not supposed to be comprehensive - when a suitable code is not enumerated here, textual or URL values can be
     used instead. These codes are at a fairly high level and do not deal with versioning and other nuance. Additional
     codes can be suggested [in github](https://github.com/schemaorg/schemaorg/issues/3057).

    See: https://schema.org/DigitalPlatformEnumeration
    Model depth: 4
    """

    type_: str = Field(default="DigitalPlatformEnumeration", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.TradeAction import TradeAction


class RentAction(TradeAction):
    """The act of giving money in return for temporary use, but not ownership, of an object such as a vehicle or property.
     For example, an agent rents a property from a landlord in exchange for a periodic payment.

    See: https://schema.org/RentAction
    Model depth: 4
    """

    type_: str = Field(default="RentAction", alias="@type", const=True)
    landlord: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A sub property of participant. The owner of the real estate property.",
    )
    realEstateAgent: Optional[
        Union[List[Union["RealEstateAgent", str]], "RealEstateAgent", str]
    ] = Field(
        default=None,
        description="A sub property of participant. The real estate agent involved in the action.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.RealEstateAgent import RealEstateAgent



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CommunicateAction import CommunicateAction


class CheckOutAction(CommunicateAction):
    """The act of an agent communicating (service provider, social media, etc) their departure of a previously reserved
     service (e.g. flight check-in) or place (e.g. hotel). Related actions: * [[CheckInAction]]: The antonym
     of CheckOutAction. * [[DepartAction]]: Unlike DepartAction, CheckOutAction implies that the agent is
     informing/confirming the end of a previously reserved service. * [[CancelAction]]: Unlike CancelAction,
     CheckOutAction implies that the agent is informing/confirming the end of a previously reserved service.

    See: https://schema.org/CheckOutAction
    Model depth: 5
    """

    type_: str = Field(default="CheckOutAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ReturnFeesEnumeration import ReturnFeesEnumeration


class ReturnFeesCustomerResponsibility(ReturnFeesEnumeration):
    """Specifies that product returns must be paid for, and are the responsibility of, the customer.

    See: https://schema.org/ReturnFeesCustomerResponsibility
    Model depth: 5
    """

    type_: str = Field(
        default="ReturnFeesCustomerResponsibility", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.SizeSystemEnumeration import SizeSystemEnumeration


class WearableSizeSystemEnumeration(SizeSystemEnumeration):
    """Enumerates common size systems specific for wearable products.

    See: https://schema.org/WearableSizeSystemEnumeration
    Model depth: 5
    """

    type_: str = Field(
        default="WearableSizeSystemEnumeration", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MusicAlbumReleaseType import MusicAlbumReleaseType


class AlbumRelease(MusicAlbumReleaseType):
    """AlbumRelease.

    See: https://schema.org/AlbumRelease
    Model depth: 5
    """

    type_: str = Field(default="AlbumRelease", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DayOfWeek import DayOfWeek


class PublicHolidays(DayOfWeek):
    """This stands for any day that is a public holiday; it is a placeholder for all official public holidays in some
     particular location. While not technically a \"day of the week\", it can be used with [[OpeningHoursSpecification]].
     In the context of an opening hours specification it can be used to indicate opening hours on public holidays,
     overriding general opening hours for the day of the week on which a public holiday occurs.

    See: https://schema.org/PublicHolidays
    Model depth: 5
    """

    type_: str = Field(default="PublicHolidays", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DigitalDocument import DigitalDocument


class TextDigitalDocument(DigitalDocument):
    """A file composed primarily of text.

    See: https://schema.org/TextDigitalDocument
    Model depth: 4
    """

    type_: str = Field(default="TextDigitalDocument", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.InteractAction import InteractAction


class UnRegisterAction(InteractAction):
    """The act of un-registering from a service. Related actions: * [[RegisterAction]]: antonym of UnRegisterAction.
     * [[LeaveAction]]: Unlike LeaveAction, UnRegisterAction implies that you are unregistering from a service
     you were previously registered, rather than leaving a team/group of people.

    See: https://schema.org/UnRegisterAction
    Model depth: 4
    """

    type_: str = Field(default="UnRegisterAction", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Action import Action


class SearchAction(Action):
    """The act of searching for an object. Related actions: * [[FindAction]]: SearchAction generally leads to a
     FindAction, but not necessarily.

    See: https://schema.org/SearchAction
    Model depth: 3
    """

    type_: str = Field(default="SearchAction", alias="@type", const=True)
    query: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A sub property of instrument. The query used on this action.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Quantity import Quantity


class Energy(Quantity):
    """Properties that take Energy as values are of the form '&lt;Number&gt; &lt;Energy unit of measure&gt;'.

    See: https://schema.org/Energy
    Model depth: 4
    """

    type_: str = Field(default="Energy", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Organization import Organization


class SearchRescueOrganization(Organization):
    """A Search and Rescue organization of some kind.

    See: https://schema.org/SearchRescueOrganization
    Model depth: 3
    """

    type_: str = Field(default="SearchRescueOrganization", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PhysicalExam import PhysicalExam


class Neuro(PhysicalExam):
    """Neurological system clinical examination.

    See: https://schema.org/Neuro
    Model depth: 5
    """

    type_: str = Field(default="Neuro", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalImagingTechnique import MedicalImagingTechnique
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty


class Radiography(MedicalImagingTechnique, MedicalSpecialty):
    """Radiography is an imaging technique that uses electromagnetic radiation other than visible light, especially
     X-rays, to view the internal structure of a non-uniformly composed and opaque object such as the human body.

    See: https://schema.org/Radiography
    Model depth: 6
    """

    type_: str = Field(default="Radiography", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.EnergyEfficiencyEnumeration import EnergyEfficiencyEnumeration


class EnergyStarEnergyEfficiencyEnumeration(EnergyEfficiencyEnumeration):
    """Used to indicate whether a product is EnergyStar certified.

    See: https://schema.org/EnergyStarEnergyEfficiencyEnumeration
    Model depth: 5
    """

    type_: str = Field(
        default="EnergyStarEnergyEfficiencyEnumeration", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.LocalBusiness import LocalBusiness


class HomeAndConstructionBusiness(LocalBusiness):
    """A construction business. A HomeAndConstructionBusiness is a [[LocalBusiness]] that provides services
     around homes and buildings. As a [[LocalBusiness]] it can be described as a [[provider]] of one or more [[Service]](s).

    See: https://schema.org/HomeAndConstructionBusiness
    Model depth: 4
    """

    type_: str = Field(default="HomeAndConstructionBusiness", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.RestrictedDiet import RestrictedDiet


class LowLactoseDiet(RestrictedDiet):
    """A diet appropriate for people with lactose intolerance.

    See: https://schema.org/LowLactoseDiet
    Model depth: 5
    """

    type_: str = Field(default="LowLactoseDiet", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.NewsArticle import NewsArticle


class OpinionNewsArticle(NewsArticle):
    """An [[OpinionNewsArticle]] is a [[NewsArticle]] that primarily expresses opinions rather than journalistic
     reporting of news and events. For example, a [[NewsArticle]] consisting of a column or [[Blog]]/[[BlogPosting]]
     entry in the Opinions section of a news publication.

    See: https://schema.org/OpinionNewsArticle
    Model depth: 5
    """

    type_: str = Field(default="OpinionNewsArticle", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Article import Article


class SatiricalArticle(Article):
    """An [[Article]] whose content is primarily [[satirical]](https://en.wikipedia.org/wiki/Satire) in
     nature, i.e. unlikely to be literally true. A satirical article is sometimes but not necessarily also a [[NewsArticle]].
     [[ScholarlyArticle]]s are also sometimes satirized.

    See: https://schema.org/SatiricalArticle
    Model depth: 4
    """

    type_: str = Field(default="SatiricalArticle", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MediaObject import MediaObject


class AudioObject(MediaObject):
    """An audio file.

    See: https://schema.org/AudioObject
    Model depth: 4
    """

    type_: str = Field(default="AudioObject", alias="@type", const=True)
    embeddedTextCaption: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Represents textual captioning from a [[MediaObject]], e.g. text of a 'meme'.",
    )
    caption: Optional[
        Union[List[Union[str, "Text", "MediaObject"]], str, "Text", "MediaObject"]
    ] = Field(
        default=None,
        description="The caption for this object. For downloadable machine formats (closed caption, subtitles etc.) use MediaObject and indicate the [[encodingFormat]].",
    )
    transcript: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="If this MediaObject is an AudioObject or VideoObject, the transcript of that object.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.MediaObject import MediaObject



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.SoftwareApplication import SoftwareApplication


class WebApplication(SoftwareApplication):
    """Web applications.

    See: https://schema.org/WebApplication
    Model depth: 4
    """

    type_: str = Field(default="WebApplication", alias="@type", const=True)
    browserRequirements: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Specifies browser requirements in human-readable text. For example, 'requires HTML5 support'.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictInt, StrictFloat
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Offer import Offer


class AggregateOffer(Offer):
    """When a single product is associated with multiple offers (for example, the same pair of shoes is offered by
     different merchants), then AggregateOffer can be used. Note: AggregateOffers are normally expected to
     associate multiple offers that all share the same defined [[businessFunction]] value, or default to http://purl.org/goodrelations/v1#Sell
     if businessFunction is not explicitly defined.

    See: https://schema.org/AggregateOffer
    Model depth: 4
    """

    type_: str = Field(default="AggregateOffer", alias="@type", const=True)
    highPrice: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str, "Text"]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
            "Text",
        ]
    ] = Field(
        default=None,
        description="The highest price of all offers available. Usage guidelines: * Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols. * Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.",
    )
    offerCount: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description="The number of offers for the product.",
    )
    lowPrice: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str, "Text"]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
            "Text",
        ]
    ] = Field(
        default=None,
        description="The lowest price of all offers available. Usage guidelines: * Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols. * Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.",
    )
    offers: Optional[
        Union[List[Union["Demand", "Offer", str]], "Demand", "Offer", str]
    ] = Field(
        default=None,
        description="An offer to provide this item&#x2014;for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]] to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a [[Demand]]. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Integer import Integer
    from pydantic2_schemaorg.Demand import Demand
    from pydantic2_schemaorg.Offer import Offer



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class WarrantyScope(Enumeration):
    """A range of services that will be provided to a customer free of charge in case of a defect or malfunction of a product.
     Commonly used values: * http://purl.org/goodrelations/v1#Labor-BringIn * http://purl.org/goodrelations/v1#PartsAndLabor-BringIn
     * http://purl.org/goodrelations/v1#PartsAndLabor-PickUp

    See: https://schema.org/WarrantyScope
    Model depth: 4
    """

    type_: str = Field(default="WarrantyScope", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Quantity import Quantity


class Duration(Quantity):
    """Quantity: Duration (use [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601)).

    See: https://schema.org/Duration
    Model depth: 4
    """

    type_: str = Field(default="Duration", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictInt, StrictFloat
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.EntertainmentBusiness import EntertainmentBusiness
from pydantic2_schemaorg.CivicStructure import CivicStructure


class MovieTheater(EntertainmentBusiness, CivicStructure):
    """A movie theater.

    See: https://schema.org/MovieTheater
    Model depth: 4
    """

    type_: str = Field(default="MovieTheater", alias="@type", const=True)
    screenCount: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The number of screens in the movie theater.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Number import Number



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.LocalBusiness import LocalBusiness


class ProfessionalService(LocalBusiness):
    """Original definition: \"provider of professional services.\" The general [[ProfessionalService]] type
     for local businesses was deprecated due to confusion with [[Service]]. For reference, the types that it included
     were: [[Dentist]], [[AccountingService]], [[Attorney]], [[Notary]], as well as types for several kinds
     of [[HomeAndConstructionBusiness]]: [[Electrician]], [[GeneralContractor]], [[HousePainter]],
     [[Locksmith]], [[Plumber]], [[RoofingContractor]]. [[LegalService]] was introduced as a more inclusive
     supertype of [[Attorney]].

    See: https://schema.org/ProfessionalService
    Model depth: 4
    """

    type_: str = Field(default="ProfessionalService", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ReactAction import ReactAction


class DisagreeAction(ReactAction):
    """The act of expressing a difference of opinion with the object. An agent disagrees to/about an object (a proposition,
     topic or theme) with participants.

    See: https://schema.org/DisagreeAction
    Model depth: 5
    """

    type_: str = Field(default="DisagreeAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class GamePlayMode(Enumeration):
    """Indicates whether this game is multi-player, co-op or single-player.

    See: https://schema.org/GamePlayMode
    Model depth: 4
    """

    type_: str = Field(default="GamePlayMode", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Action import Action


class ControlAction(Action):
    """An agent controls a device or application.

    See: https://schema.org/ControlAction
    Model depth: 3
    """

    type_: str = Field(default="ControlAction", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.TransferAction import TransferAction


class DonateAction(TransferAction):
    """The act of providing goods, services, or money without compensation, often for philanthropic reasons.

    See: https://schema.org/DonateAction
    Model depth: 4
    """

    type_: str = Field(default="DonateAction", alias="@type", const=True)
    priceCurrency: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='The currency of the price, or a price component when attached to [[PriceSpecification]] and its subtypes. Use standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. "USD"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. "BTC"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. "Ithaca HOUR".',
    )
    recipient: Optional[
        Union[
            List[Union["Organization", "Audience", "Person", "ContactPoint", str]],
            "Organization",
            "Audience",
            "Person",
            "ContactPoint",
            str,
        ]
    ] = Field(
        default=None,
        description="A sub property of participant. The participant who is at the receiving end of the action.",
    )
    price: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str, "Text"]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
            "Text",
        ]
    ] = Field(
        default=None,
        description="The offer price of a product, or of a price component when attached to PriceSpecification and its subtypes. Usage guidelines: * Use the [[priceCurrency]] property (with standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. \"USD\"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. \"BTC\"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. \"Ithaca HOUR\") instead of including [ambiguous symbols](http://en.wikipedia.org/wiki/Dollar_sign#Currencies_that_use_the_dollar_or_peso_sign) such as '$' in the value. * Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator. * Note that both [RDFa](http://www.w3.org/TR/xhtml-rdfa-primer/#using-the-content-attribute) and Microdata syntax allow the use of a \"content=\" attribute for publishing simple machine-readable values alongside more human-friendly formatting. * Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.",
    )
    priceSpecification: Optional[
        Union[List[Union["PriceSpecification", str]], "PriceSpecification", str]
    ] = Field(
        default=None,
        description="One or more detailed price specifications, indicating the unit price and delivery or payment charges.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Audience import Audience
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.ContactPoint import ContactPoint
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.PriceSpecification import PriceSpecification



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ReservationStatusType import ReservationStatusType


class ReservationHold(ReservationStatusType):
    """The status of a reservation on hold pending an update like credit card number or flight changes.

    See: https://schema.org/ReservationHold
    Model depth: 6
    """

    type_: str = Field(default="ReservationHold", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class PriceTypeEnumeration(Enumeration):
    """Enumerates different price types, for example list price, invoice price, and sale price.

    See: https://schema.org/PriceTypeEnumeration
    Model depth: 4
    """

    type_: str = Field(default="PriceTypeEnumeration", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class ServiceChannel(Intangible):
    """A means for accessing a service, e.g. a government office location, web site, or phone number.

    See: https://schema.org/ServiceChannel
    Model depth: 3
    """

    type_: str = Field(default="ServiceChannel", alias="@type", const=True)
    availableLanguage: Optional[
        Union[List[Union[str, "Text", "Language"]], str, "Text", "Language"]
    ] = Field(
        default=None,
        description="A language someone may use with or at the item, service or place. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also [[inLanguage]].",
    )
    serviceLocation: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="The location (e.g. civic structure, local business, etc.) where a person can go to access the service.",
    )
    serviceUrl: Optional[Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]] = (
        Field(
            default=None,
            description="The website to access the service.",
        )
    )
    serviceSmsNumber: Optional[
        Union[List[Union["ContactPoint", str]], "ContactPoint", str]
    ] = Field(
        default=None,
        description="The number to access the service by text message.",
    )
    servicePostalAddress: Optional[
        Union[List[Union["PostalAddress", str]], "PostalAddress", str]
    ] = Field(
        default=None,
        description="The address for accessing the service by mail.",
    )
    providesService: Optional[Union[List[Union["Service", str]], "Service", str]] = (
        Field(
            default=None,
            description="The service provided by this channel.",
        )
    )
    processingTime: Optional[Union[List[Union["Duration", str]], "Duration", str]] = (
        Field(
            default=None,
            description="Estimated processing time for the service using this channel.",
        )
    )
    servicePhone: Optional[
        Union[List[Union["ContactPoint", str]], "ContactPoint", str]
    ] = Field(
        default=None,
        description="The phone number to use to access the service.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Language import Language
    from pydantic2_schemaorg.Place import Place
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.ContactPoint import ContactPoint
    from pydantic2_schemaorg.PostalAddress import PostalAddress
    from pydantic2_schemaorg.Service import Service
    from pydantic2_schemaorg.Duration import Duration



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.PlayAction import PlayAction


class ExerciseAction(PlayAction):
    """The act of participating in exertive activity for the purposes of improving health and fitness.

    See: https://schema.org/ExerciseAction
    Model depth: 4
    """

    type_: str = Field(default="ExerciseAction", alias="@type", const=True)
    exercisePlan: Optional[
        Union[List[Union["ExercisePlan", str]], "ExercisePlan", str]
    ] = Field(
        default=None,
        description="A sub property of instrument. The exercise plan used on this action.",
    )
    exerciseCourse: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="A sub property of location. The course where this action was taken.",
    )
    sportsActivityLocation: Optional[
        Union[List[Union["SportsActivityLocation", str]], "SportsActivityLocation", str]
    ] = Field(
        default=None,
        description="A sub property of location. The sports activity location where this action occurred.",
    )
    exerciseType: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Type(s) of exercise or activity, such as strength training, flexibility training, aerobics, cardiac rehabilitation, etc.",
    )
    opponent: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="A sub property of participant. The opponent on this action.",
    )
    exerciseRelatedDiet: Optional[Union[List[Union["Diet", str]], "Diet", str]] = Field(
        default=None,
        description="A sub property of instrument. The diet used in this action.",
    )
    diet: Optional[Union[List[Union["Diet", str]], "Diet", str]] = Field(
        default=None,
        description="A sub property of instrument. The diet used in this action.",
    )
    course: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="A sub property of location. The course where this action was taken.",
    )
    toLocation: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="A sub property of location. The final location of the object or the agent after the action.",
    )
    sportsTeam: Optional[Union[List[Union["SportsTeam", str]], "SportsTeam", str]] = (
        Field(
            default=None,
            description="A sub property of participant. The sports team that participated on this action.",
        )
    )
    fromLocation: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="A sub property of location. The original location of the object or the agent before the action.",
    )
    sportsEvent: Optional[
        Union[List[Union["SportsEvent", str]], "SportsEvent", str]
    ] = Field(
        default=None,
        description="A sub property of location. The sports event where this action occurred.",
    )
    distance: Optional[Union[List[Union["Distance", str]], "Distance", str]] = Field(
        default=None,
        description="The distance travelled, e.g. exercising or travelling.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.ExercisePlan import ExercisePlan
    from pydantic2_schemaorg.Place import Place
    from pydantic2_schemaorg.SportsActivityLocation import SportsActivityLocation
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Diet import Diet
    from pydantic2_schemaorg.SportsTeam import SportsTeam
    from pydantic2_schemaorg.SportsEvent import SportsEvent
    from pydantic2_schemaorg.Distance import Distance



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.InvestmentOrDeposit import InvestmentOrDeposit
from pydantic2_schemaorg.BankAccount import BankAccount


class DepositAccount(InvestmentOrDeposit, BankAccount):
    """A type of Bank Account with a main purpose of depositing funds to gain interest or other benefits.

    See: https://schema.org/DepositAccount
    Model depth: 6
    """

    type_: str = Field(default="DepositAccount", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalAudienceType import MedicalAudienceType


class Clinician(MedicalAudienceType):
    """Medical clinicians, including practicing physicians and other medical professionals involved in clinical
     practice.

    See: https://schema.org/Clinician
    Model depth: 6
    """

    type_: str = Field(default="Clinician", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.GameAvailabilityEnumeration import GameAvailabilityEnumeration


class DemoGameAvailability(GameAvailabilityEnumeration):
    """Indicates demo game availability, i.e. a somehow limited demonstration of the full game.

    See: https://schema.org/DemoGameAvailability
    Model depth: 5
    """

    type_: str = Field(default="DemoGameAvailability", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalBusiness import MedicalBusiness
from pydantic2_schemaorg.MedicalOrganization import MedicalOrganization
from pydantic2_schemaorg.LocalBusiness import LocalBusiness


class Dentist(MedicalBusiness, MedicalOrganization, LocalBusiness):
    """A dentist.

    See: https://schema.org/Dentist
    Model depth: 4
    """

    type_: str = Field(default="Dentist", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.TierBenefitEnumeration import TierBenefitEnumeration


class TierBenefitLoyaltyShipping(TierBenefitEnumeration):
    """Benefit of the tier is a members-only shipping price or speed (for example free shipping or 1-day shipping).

    See: https://schema.org/TierBenefitLoyaltyShipping
    Model depth: 5
    """

    type_: str = Field(default="TierBenefitLoyaltyShipping", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ConsumeAction import ConsumeAction


class UseAction(ConsumeAction):
    """The act of applying an object to its intended purpose.

    See: https://schema.org/UseAction
    Model depth: 4
    """

    type_: str = Field(default="UseAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HealthAndBeautyBusiness import HealthAndBeautyBusiness


class TattooParlor(HealthAndBeautyBusiness):
    """A tattoo parlor.

    See: https://schema.org/TattooParlor
    Model depth: 5
    """

    type_: str = Field(default="TattooParlor", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.USNonprofitType import USNonprofitType


class Nonprofit501c17(USNonprofitType):
    """Nonprofit501c17: Non-profit type referring to Supplemental Unemployment Benefit Trusts.

    See: https://schema.org/Nonprofit501c17
    Model depth: 6
    """

    type_: str = Field(default="Nonprofit501c17", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Review import Review


class Recommendation(Review):
    """[[Recommendation]] is a type of [[Review]] that suggests or proposes something as the best option or best
     course of action. Recommendations may be for products or services, or other concrete things, as in the case
     of a ranked list or product guide. A [[Guide]] may list multiple recommendations for different categories.
     For example, in a [[Guide]] about which TVs to buy, the author may have several [[Recommendation]]s.

    See: https://schema.org/Recommendation
    Model depth: 4
    """

    type_: str = Field(default="Recommendation", alias="@type", const=True)
    category: Optional[
        Union[
            List[
                Union[
                    AnyUrl,
                    "URL",
                    str,
                    "Text",
                    "PhysicalActivityCategory",
                    "CategoryCode",
                    "Thing",
                ]
            ],
            AnyUrl,
            "URL",
            str,
            "Text",
            "PhysicalActivityCategory",
            "CategoryCode",
            "Thing",
        ]
    ] = Field(
        default=None,
        description="A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory
    from pydantic2_schemaorg.CategoryCode import CategoryCode
    from pydantic2_schemaorg.Thing import Thing



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.USNonprofitType import USNonprofitType


class Nonprofit501c18(USNonprofitType):
    """Nonprofit501c18: Non-profit type referring to Employee Funded Pension Trust (created before 25 June 1959).

    See: https://schema.org/Nonprofit501c18
    Model depth: 6
    """

    type_: str = Field(default="Nonprofit501c18", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWorkSeason import CreativeWorkSeason


class RadioSeason(CreativeWorkSeason):
    """Season dedicated to radio broadcast and associated online delivery.

    See: https://schema.org/RadioSeason
    Model depth: 4
    """

    type_: str = Field(default="RadioSeason", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Action import Action


class CreateAction(Action):
    """The act of deliberately creating/producing/generating/building a result out of the agent.

    See: https://schema.org/CreateAction
    Model depth: 3
    """

    type_: str = Field(default="CreateAction", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class MenuItem(Intangible):
    """A food or drink item listed in a menu or menu section.

    See: https://schema.org/MenuItem
    Model depth: 3
    """

    type_: str = Field(default="MenuItem", alias="@type", const=True)
    nutrition: Optional[
        Union[List[Union["NutritionInformation", str]], "NutritionInformation", str]
    ] = Field(
        default=None,
        description="Nutrition information about the recipe or menu item.",
    )
    suitableForDiet: Optional[
        Union[List[Union["RestrictedDiet", str]], "RestrictedDiet", str]
    ] = Field(
        default=None,
        description="Indicates a dietary restriction or guideline for which this recipe or menu item is suitable, e.g. diabetic, halal etc.",
    )
    offers: Optional[
        Union[List[Union["Demand", "Offer", str]], "Demand", "Offer", str]
    ] = Field(
        default=None,
        description="An offer to provide this item&#x2014;for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]] to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a [[Demand]]. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.",
    )
    menuAddOn: Optional[
        Union[
            List[Union["MenuItem", "MenuSection", str]], "MenuItem", "MenuSection", str
        ]
    ] = Field(
        default=None,
        description="Additional menu item(s) such as a side dish of salad or side order of fries that can be added to this menu item. Additionally it can be a menu section containing allowed add-on menu items for this menu item.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.NutritionInformation import NutritionInformation
    from pydantic2_schemaorg.RestrictedDiet import RestrictedDiet
    from pydantic2_schemaorg.Demand import Demand
    from pydantic2_schemaorg.Offer import Offer
    from pydantic2_schemaorg.MenuSection import MenuSection



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Text import Text


class XPathType(Text):
    """Text representing an XPath (typically but not necessarily version 1.0).

    See: https://schema.org/XPathType
    Model depth: 6
    """

    type_: str = Field(default="XPathType", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AllocateAction import AllocateAction


class RejectAction(AllocateAction):
    """The act of rejecting to/adopting an object. Related actions: * [[AcceptAction]]: The antonym of RejectAction.

    See: https://schema.org/RejectAction
    Model depth: 5
    """

    type_: str = Field(default="RejectAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration


class HowItWorksHealthAspect(HealthAspectEnumeration):
    """Content that discusses and explains how a particular health-related topic works, e.g. in terms of mechanisms
     and underlying science.

    See: https://schema.org/HowItWorksHealthAspect
    Model depth: 5
    """

    type_: str = Field(default="HowItWorksHealthAspect", alias="@type", const=True)



__all__ = [
    "SchemaOrgBase",
    "Thing",
    "Place",
    "Organization",
    "Intangible",
    "CreativeWork",
    "Event",
    "Product",
    "MedicalEntity",
    "Action",
    "BioChemEntity",
    "Taxon",
    "Person",
    "LocalBusiness",
    "Enumeration",
    "HealthInsurancePlan",
    "Article",
    "PublicationEvent",
    "GovernmentOrganization",
    "Vehicle",
    "GeospatialGeometry",
    "Ticket",
    "AnatomicalStructure",
    "MediaObject",
    "MedicalCondition",
    "Accommodation",
    "OrderItem",
    "InteractAction",
    "CivicStructure",
    "Map",
    "Comment",
    "UserInteraction",
    "DefinedTermSet",
    "Clip",
    "SomeProducts",
    "Demand",
    "SocialEvent",
    "ListItem",
    "ItemList",
    "HowToSection",
    "Residence",
    "OrganizeAction",
    "Quantity",
    "SoftwareApplication",
    "TransferAction",
    "MedicalProcedure",
    "TradeAction",
    "HowTo",
    "StructuredValue",
    "FoodEvent",
    "Service",
    "PaymentMethod",
    "Game",
    "Airline",
    "ServiceChannel",
    "DataCatalog",
    "MerchantReturnPolicy",
    "MedicalOrganization",
    "Reservation",
    "EntryPoint",
    "MedicalStudy",
    "WebPageElement",
    "SheetMusic",
    "EducationalOccupationalProgram",
    "Dataset",
    "MedicalTest",
    "Message",
    "WorkersUnion",
    "SolveMathAction",
    "MoveAction",
    "WebPage",
    "Landform",
    "EducationalOrganization",
    "NGO",
    "TheaterEvent",
    "Photograph",
    "AdministrativeArea",
    "Audience",
    "Trip",
    "AssessAction",
    "Offer",
    "Role",
    "Series",
    "CreativeWorkSeries",
    "Episode",
    "Protein",
    "Thesis",
    "GameServer",
    "Permit",
    "MusicEvent",
    "BroadcastChannel",
    "EnergyConsumptionDetails",
    "DigitalDocument",
    "WebContent",
    "PropertyValueSpecification",
    "LearningResource",
    "ChildrensEvent",
    "SoftwareSourceCode",
    "Sculpture",
    "Code",
    "ConsumeAction",
    "DefinedTerm",
    "Manuscript",
    "Observation",
    "Grant",
    "PerformingGroup",
    "HealthPlanFormulary",
    "Property",
    "CreateAction",
    "Corporation",
    "VirtualLocation",
    "Rating",
    "FindAction",
    "MedicalIntangible",
    "MedicalIndication",
    "Quotation",
    "Review",
    "ChemicalSubstance",
    "LifestyleModification",
    "Conversation",
    "Drawing",
    "Class",
    "PlayAction",
    "Schedule",
    "CreativeWorkSeason",
    "EducationalOccupationalCredential",
    "HealthPlanNetwork",
    "Play",
    "LiteraryEvent",
    "VisualArtwork",
    "BusinessEvent",
    "JobPosting",
    "MemberProgram",
    "Claim",
    "ControlAction",
    "UpdateAction",
    "PublicationIssue",
    "ComicStory",
    "ActionAccessSpecification",
    "Statement",
    "Patient",
    "MedicalContraindication",
    "StatisticalPopulation",
    "SearchRescueOrganization",
    "AchieveAction",
    "ProgramMembership",
    "IndividualProduct",
    "Occupation",
    "ProductModel",
    "CourseInstance",
    "ComedyEvent",
    "ComputerLanguage",
    "Invoice",
    "ResearchOrganization",
    "MerchantReturnPolicySeasonalOverride",
    "SportsEvent",
    "ParcelDelivery",
    "Legislation",
    "MedicalRiskEstimator",
    "Project",
    "MedicalDevice",
    "Language",
    "HealthPlanCostSharingSpecification",
    "Hackathon",
    "HowToTip",
    "SearchAction",
    "MedicalCause",
    "Collection",
    "ProductGroup",
    "ArchiveComponent",
    "SaleEvent",
    "DrugClass",
    "OnlineBusiness",
    "Course",
    "Chapter",
    "SeekToAction",
    "PoliticalParty",
    "SportsOrganization",
    "HowToDirection",
    "SpeakableSpecification",
    "Substance",
    "DietarySupplement",
    "PublicationVolume",
    "MolecularEntity",
    "TouristDestination",
    "MedicalRiskFactor",
    "Guide",
    "MusicComposition",
    "DeliveryEvent",
    "MusicPlaylist",
    "Book",
    "Seat",
    "SpecialAnnouncement",
    "MenuItem",
    "Diet",
    "VisualArtsEvent",
    "MemberProgramTier",
    "MediaReviewItem",
    "FundingScheme",
    "WebSite",
    "MathSolver",
    "MenuSection",
    "HowToStep",
    "BedDetails",
    "Consortium",
    "AlignmentObject",
    "AmpStory",
    "Movie",
    "ExercisePlan",
    "DanceEvent",
    "Certification",
    "Blog",
    "TVSeason",
    "ScreeningEvent",
    "MedicalGuideline",
    "DataFeedItem",
    "Festival",
    "Drug",
    "HyperTocEntry",
    "ShortStory",
    "Atlas",
    "Brand",
    "EventSeries",
    "DigitalDocumentPermission",
    "NewsMediaOrganization",
    "ConstraintNode",
    "Menu",
    "LibrarySystem",
    "TVSeries",
    "DrugCost",
    "MediaSubscription",
    "Painting",
    "Order",
    "SuperficialAnatomy",
    "LandmarksOrHistoricalBuildings",
    "AnatomicalSystem",
    "FloorPlan",
    "MusicRecording",
    "ExhibitionEvent",
    "HyperToc",
    "OccupationalExperienceRequirements",
    "ProductCollection",
    "BroadcastFrequencySpecification",
    "Gene",
    "Season",
    "TouristAttraction",
    "Poster",
    "EducationEvent",
    "FoodEstablishment",
    "MedicalEnumeration",
    "StatusEnumeration",
    "HealthAspectEnumeration",
    "MusicReleaseFormatType",
    "PaymentMethodType",
    "PriceComponentTypeEnumeration",
    "SocialMediaPosting",
    "OnDemandEvent",
    "BookFormatType",
    "Motorcycle",
    "BrainStructure",
    "MusicVideoObject",
    "MedicalSignOrSymptom",
    "CampingPitch",
    "FollowAction",
    "ScholarlyArticle",
    "PlaceOfWorship",
    "QualitativeValue",
    "AdultOrientedEnumeration",
    "CorrectionComment",
    "MeasurementTypeEnumeration",
    "UserPageVisits",
    "CommunicateAction",
    "MediaEnumeration",
    "EnergyEfficiencyEnumeration",
    "SizeSystemEnumeration",
    "MediaManipulationRatingEnumeration",
    "MotorizedBicycle",
    "EntertainmentBusiness",
    "ItemListOrderType",
    "Specialty",
    "AllocateAction",
    "Energy",
    "WebApplication",
    "DownloadAction",
    "NonprofitType",
    "TherapeuticProcedure",
    "ReturnMethodEnumeration",
    "ImageObject",
    "Duration",
    "QuoteAction",
    "PriceTypeEnumeration",
    "Recipe",
    "PriceSpecification",
    "AutomotiveBusiness",
    "FinancialProduct",
    "PaymentCard",
    "QuantitativeValueDistribution",
    "RadioClip",
    "SizeGroupEnumeration",
    "MedicalBusiness",
    "DigitalDocumentPermissionType",
    "RestrictedDiet",
    "EmergencyService",
    "Hospital",
    "RentalCarReservation",
    "SurgicalProcedure",
    "GovernmentBenefitsType",
    "MapCategoryType",
    "MedicalTrial",
    "GovernmentBuilding",
    "DayOfWeek",
    "Store",
    "PublicToilet",
    "Physician",
    "CarUsageType",
    "WorkBasedProgram",
    "HomeAndConstructionBusiness",
    "DataFeed",
    "EmailMessage",
    "ShippingDeliveryTime",
    "LegalService",
    "BroadcastEvent",
    "NewsArticle",
    "UserTweets",
    "RVPark",
    "ParkingFacility",
    "Room",
    "LodgingBusiness",
    "HealthAndBeautyBusiness",
    "DiagnosticLab",
    "MerchantReturnEnumeration",
    "TravelAction",
    "RsvpResponseType",
    "CollectionPage",
    "BodyOfWater",
    "HighSchool",
    "TaxiService",
    "SubwayStation",
    "DiagnosticProcedure",
    "Campground",
    "PhysicalExam",
    "OfferCatalog",
    "Country",
    "Researcher",
    "TrainTrip",
    "FinancialService",
    "ChooseAction",
    "OfferForPurchase",
    "ReactAction",
    "PerformanceRole",
    "UserLikes",
    "Bridge",
    "QuantitativeValue",
    "Table",
    "BusinessAudience",
    "ReturnFeesEnumeration",
    "PropertyValue",
    "GovernmentPermit",
    "AggregateOffer",
    "TextObject",
    "Bone",
    "TrainStation",
    "RadioSeries",
    "NoteDigitalDocument",
    "PodcastSeries",
    "ItemAvailability",
    "HealthTopicContent",
    "InternetCafe",
    "Vessel",
    "DigitalPlatformEnumeration",
    "SportsActivityLocation",
    "FAQPage",
    "LegalValueLevel",
    "RefundTypeEnumeration",
    "GenderType",
    "Flight",
    "ReturnLabelSourceEnumeration",
    "UserCheckins",
    "EatAction",
    "LeaveAction",
    "City",
    "UseAction",
    "GamePlayMode",
    "InfectiousDisease",
    "DonateAction",
    "GameAvailabilityEnumeration",
    "OfferShippingDetails",
    "ApartmentComplex",
    "BusStation",
    "TrainReservation",
    "LendAction",
    "MonetaryGrant",
    "DanceGroup",
    "Ligament",
    "InstallAction",
    "Airport",
    "House",
    "GovernmentOffice",
    "VideoGameSeries",
    "ViewAction",
    "OfferItemCondition",
    "PhotographAction",
    "TechArticle",
    "BloodTest",
    "BorrowAction",
    "MedicalTestPanel",
    "EndorsementRating",
    "PlanAction",
    "TaxiStand",
    "DoseSchedule",
    "TreatmentIndication",
    "RepaymentSpecification",
    "BookmarkAction",
    "CertificationStatusEnumeration",
    "PlayGameAction",
    "WarrantyScope",
    "WebAPI",
    "PhysicalActivity",
    "BusinessFunction",
    "UnRegisterAction",
    "RadioChannel",
    "Continent",
    "MusicGroup",
    "DataType",
    "PerformAction",
    "MedicalObservationalStudy",
    "Suite",
    "MusicAlbumProductionType",
    "AnimalShelter",
    "CriticReview",
    "UserReview",
    "TelevisionChannel",
    "MedicalConditionStage",
    "ListenAction",
    "MediaReview",
    "OrganizationRole",
    "WPFooter",
    "CoverArt",
    "TaxiReservation",
    "RadioEpisode",
    "CategoryCode",
    "DDxElement",
    "Beach",
    "ProfilePage",
    "ChildCare",
    "ApplyAction",
    "Mass",
    "BookSeries",
    "IgnoreAction",
    "AddAction",
    "ComicIssue",
    "ComicCoverArt",
    "ContactPointOption",
    "EmployerReview",
    "GovernmentService",
    "ReviewAction",
    "MoneyTransfer",
    "MobileApplication",
    "MeasurementMethodEnum",
    "TheaterGroup",
    "DefinedRegion",
    "PeopleAudience",
    "MedicalAudience",
    "ReturnAction",
    "FoodService",
    "PathologyTest",
    "AdvertiserContentArticle",
    "PhysicalActivityCategory",
    "BoardingPolicyType",
    "SchoolDistrict",
    "Periodical",
    "VideoGame",
    "BuyAction",
    "Cemetery",
    "FilmAction",
    "MusicAlbumReleaseType",
    "EducationalAudience",
    "MiddleSchool",
    "TypeAndQuantityNode",
    "UserPlusOnes",
    "BoatTrip",
    "Apartment",
    "DryCleaningOrLaundry",
    "PostalCodeRangeSpecification",
    "SuspendAction",
    "TierBenefitEnumeration",
    "DiscoverAction",
    "MovieSeries",
    "ElementarySchool",
    "AudioObject",
    "WatchAction",
    "SellAction",
    "ApprovedIndication",
    "TrackAction",
    "TravelAgency",
    "BusinessEntityType",
    "FireStation",
    "Muscle",
    "_3DModel",
    "MedicalClinic",
    "BroadcastService",
    "BreadcrumbList",
    "BefriendAction",
    "ContactPoint",
    "CDCPMDRecord",
    "DepartAction",
    "RadioSeason",
    "ResumeAction",
    "FundingAgency",
    "JoinAction",
    "DeactivateAction",
    "GatedResidenceCommunity",
    "NutritionInformation",
    "Library",
    "Question",
    "ShippingRateSettings",
    "OnlineStore",
    "InteractionCounter",
    "Quiz",
    "UserPlays",
    "ShoppingCenter",
    "PresentationDigitalDocument",
    "GeoShape",
    "Taxi",
    "ReservationPackage",
    "MedicalWebPage",
    "DeliveryTimeSettings",
    "PalliativeProcedure",
    "PoliceStation",
    "RealEstateAgent",
    "DeliveryMethod",
    "DatedMoneySpecification",
    "UserBlocks",
    "RegisterAction",
    "PodcastEpisode",
    "EventAttendanceModeEnumeration",
    "Nerve",
    "MedicalCode",
    "TakeAction",
    "SearchResultsPage",
    "MedicalRiskScore",
    "OfferForLease",
    "CheckoutPage",
    "PaymentService",
    "ProfessionalService",
    "ArchiveOrganization",
    "CategoryCodeSet",
    "CollegeOrUniversity",
    "CookAction",
    "Pharmacy",
    "AggregateRating",
    "LodgingReservation",
    "AboutPage",
    "Report",
    "LoseAction",
    "BusReservation",
    "MusicRelease",
    "Syllabus",
    "TouristInformationCenter",
    "SiteNavigationElement",
    "PreventionIndication",
    "Audiobook",
    "MedicalRiskCalculator",
    "EventVenue",
    "DrugLegalStatus",
    "MovieClip",
    "State",
    "ReceiveAction",
    "DrawAction",
    "SendAction",
    "Crematorium",
    "UserComments",
    "TieAction",
    "HowToItem",
    "VideoObject",
    "ImagingTest",
    "OrderAction",
    "SportsTeam",
    "SatiricalArticle",
    "WinAction",
    "PerformingArtsTheater",
    "PaintAction",
    "WarrantyPromise",
    "PayAction",
    "RecyclingCenter",
    "TouristTrip",
    "TipAction",
    "ResearchProject",
    "FlightReservation",
    "SpreadsheetDigitalDocument",
    "TelevisionStation",
    "RealEstateListing",
    "Recommendation",
    "GeoCoordinates",
    "ActivateAction",
    "Car",
    "EventReservation",
    "MedicalGuidelineContraindication",
    "MonetaryAmount",
    "SubscribeAction",
    "FoodEstablishmentReservation",
    "WriteAction",
    "VideoGameClip",
    "BusTrip",
    "WPAdBlock",
    "QAPage",
    "DrugStrength",
    "TVClip",
    "EmploymentAgency",
    "DeleteAction",
    "School",
    "GiveAction",
    "Preschool",
    "Playground",
    "TextDigitalDocument",
    "CableOrSatelliteService",
    "ReplaceAction",
    "RadioStation",
    "RentAction",
    "TVEpisode",
    "MovieTheater",
    "Answer",
    "WPSideBar",
    "PodcastSeason",
    "Volcano",
    "OpeningHoursSpecification",
    "StadiumOrArena",
    "Distance",
    "ArriveAction",
    "SelfStorage",
    "ItemPage",
    "VeterinaryCare",
    "ExchangeRateSpecification",
    "LinkRole",
    "MarryAction",
    "MusicAlbum",
    "Aquarium",
    "PreOrderAction",
    "ReadAction",
    "BoatReservation",
    "BoatTerminal",
    "MusicVenue",
    "OwnershipInfo",
    "StatisticalVariable",
    "EngineSpecification",
    "DrinkAction",
    "BusOrCoach",
    "BusStop",
    "DataDownload",
    "UserDownloads",
    "LegislationObject",
    "Mountain",
    "ExerciseAction",
    "CheckAction",
    "ContactPage",
    "ClaimReview",
    "Museum",
    "Joint",
    "Zoo",
    "MedicalGuidelineRecommendation",
    "WPHeader",
    "Dentist",
    "Park",
    "IceCreamShop",
    "MedicalTrialDesign",
    "PaymentStatusType",
    "MayTreatHealthAspect",
    "LaserDiscFormat",
    "PhoneCarrierPayment",
    "DiscussionForumPosting",
    "Hardcover",
    "DigitalFormat",
    "DVDFormat",
    "MedicalSign",
    "EventStatusType",
    "OrderStatus",
    "DriveWheelConfigurationValue",
    "TobaccoNicotineConsideration",
    "WearableMeasurementTypeEnumeration",
    "MedicalImagingTechnique",
    "CheckInAction",
    "ReservationStatusType",
    "IPTCDigitalSourceEnumeration",
    "EUEnergyEfficiencyEnumeration",
    "WearableSizeSystemEnumeration",
    "SatireOrParodyContent",
    "ArtGallery",
    "ItemListOrderAscending",
    "AllergiesHealthAspect",
    "Bakery",
    "MedicalSpecialty",
    "AcceptAction",
    "SelfCareHealthAspect",
    "USNonprofitType",
    "MedicalTherapy",
    "ReturnByMail",
    "Barcode",
    "CheckOutAction",
    "InvoicePrice",
    "SideEffectsHealthAspect",
    "CompoundPriceSpecification",
    "MedicineSystem",
    "DrugPrescriptionStatus",
    "LoanOrCredit",
    "CreditCard",
    "InStorePrepay",
    "WearableSizeGroupEnumeration",
    "DietNutrition",
    "CommentPermission",
    "Nursing",
    "VeganDiet",
    "MedicalProcedureType",
    "AutoDealer",
    "SalePrice",
    "SeatingMap",
    "OverviewHealthAspect",
    "TypesHealthAspect",
    "CityHall",
    "Tuesday",
    "LiquorStore",
    "Downpayment",
    "PhysiciansOffice",
    "RentalVehicleUsage",
    "InfectiousAgentClass",
    "RoofingContractor",
    "DrugCostCategory",
    "GameServerStatus",
    "Notary",
    "CausesHealthAspect",
    "ReportageNewsArticle",
    "IngredientsHealthAspect",
    "MeetingRoom",
    "BodyMeasurementTypeEnumeration",
    "AmusementPark",
    "PaidLeave",
    "BedAndBreakfast",
    "DrugPregnancyCategory",
    "GardenStore",
    "MerchantReturnUnspecified",
    "MediaGallery",
    "SafetyHealthAspect",
    "NailSalon",
    "RiverBodyOfWater",
    "PsychologicalTreatment",
    "Plumber",
    "ShareAction",
    "OceanBodyOfWater",
    "FastFoodRestaurant",
    "DistanceFee",
    "MedicalEvidenceLevel",
    "Nose",
    "BarOrPub",
    "MedicalStudyStatus",
    "InsuranceAgency",
    "VoteAction",
    "EndorseAction",
    "ContagiousnessHealthAspect",
    "MensClothingStore",
    "SizeSpecification",
    "LowLactoseDiet",
    "ToyStore",
    "Sunday",
    "AdultEntertainment",
    "InvestmentOrDeposit",
    "RestockingFees",
    "LocationFeatureSpecification",
    "MedicalObservationalStudyDesign",
    "ReturnInStore",
    "LowSaltDiet",
    "DecontextualizedContent",
    "UKNonprofitType",
    "Geriatric",
    "Vein",
    "Skin",
    "AndroidPlatform",
    "PublicSwimmingPool",
    "FreeReturn",
    "MSRP",
    "AutoPartsStore",
    "AuthoritativeLegalValue",
    "PawnShop",
    "ExchangeRefund",
    "SeeDoctorHealthAspect",
    "HVACBusiness",
    "MisconceptionsHealthAspect",
    "Midwifery",
    "MerchantReturnUnlimitedWindow",
    "Cash",
    "Reserved",
    "RegularPrice",
    "NLNonprofitType",
    "DiabeticDiet",
    "WearAction",
    "MerchantReturnNotPermitted",
    "DemoGameAvailability",
    "Thursday",
    "PreSale",
    "Synagogue",
    "EnergyStarEnergyEfficiencyEnumeration",
    "Wednesday",
    "Locksmith",
    "HalalDiet",
    "RefurbishedCondition",
    "DrivingSchoolVehicleUsage",
    "BookStore",
    "ReserveAction",
    "IOSPlatform",
    "RelatedTopicsHealthAspect",
    "MaximumDoseSchedule",
    "PublicHealth",
    "ImageObjectSnapshot",
    "ReturnAtKiosk",
    "GeneralContractor",
    "LowFatDiet",
    "BankAccount",
    "DigitalAudioTapeFormat",
    "ConvenienceStore",
    "AMRadioChannel",
    "CleaningFee",
    "PreventionHealthAspect",
    "MedicalDevicePurpose",
    "Number",
    "InformAction",
    "DisagreeAction",
    "MedicalAudienceType",
    "UnitPriceSpecification",
    "Electrician",
    "OriginalMediaContent",
    "StudioAlbum",
    "HairSalon",
    "OfficialLegalValue",
    "ReviewNewsArticle",
    "SportingGoodsStore",
    "Brewery",
    "Subscription",
    "Optician",
    "ReturnShippingFees",
    "Gynecologic",
    "Waterfall",
    "FullRefund",
    "AutoRepair",
    "Friday",
    "StoreCreditRefund",
    "ItemListOrderDescending",
    "LegalForceStatus",
    "HobbyShop",
    "Reservoir",
    "Text",
    "Pediatric",
    "Paperback",
    "Boolean",
    "NarcoticConsideration",
    "VacationRental",
    "InsertAction",
    "EffectivenessHealthAspect",
    "Resort",
    "GasStation",
    "MobileWebPlatform",
    "LegislativeBuilding",
    "DeliveryChargeSpecification",
    "GenericWebPlatform",
    "TollFree",
    "MotorcycleRepair",
    "LymphaticVessel",
    "HowOrWhereHealthAspect",
    "Restaurant",
    "DangerousGoodConsideration",
    "BedType",
    "NewCondition",
    "Podiatric",
    "ExampleMeasurementMethodEnum",
    "MobilePhoneStore",
    "DisabilitySupport",
    "CertificationInactive",
    "ReturnLabelCustomerResponsibility",
    "LeisureTimeActivity",
    "OneTimePayments",
    "ParentalSupport",
    "ReturnLabelDownloadAndPrint",
    "AskAction",
    "RsvpResponseMaybe",
    "SinglePlayer",
    "HotelRoom",
    "Newspaper",
    "ActivationFee",
    "CheckInAdvance",
    "PublicHolidays",
    "WantAction",
    "ReplyAction",
    "Winery",
    "VegetarianDiet",
    "Head",
    "SingleRelease",
    "InStoreOnly",
    "CardiovascularExam",
    "AlcoholConsideration",
    "TierBenefitLoyaltyShipping",
    "BackOrder",
    "ViolenceConsideration",
    "Emergency",
    "Genitourinary",
    "BlogPosting",
    "SexualContentConsideration",
    "AudioObjectSnapshot",
    "HinduDiet",
    "TransformedContent",
    "Ear",
    "AutoBodyShop",
    "CoOp",
    "RisksOrComplicationsHealthAspect",
    "StagesHealthAspect",
    "PaymentChargeSpecification",
    "TennisComplex",
    "SportsClub",
    "WritePermission",
    "LiveAlbum",
    "OccupationalActivity",
    "AccountingService",
    "PreOrder",
    "UnclassifiedAdultConsideration",
    "OnlineOnly",
    "UnofficialLegalValue",
    "CDFormat",
    "GlutenFreeDiet",
    "AuthorizeAction",
    "TireShop",
    "VinylFormat",
    "SingleFamilyResidence",
    "AerobicActivity",
    "CompleteDataFeed",
    "MixtapeAlbum",
    "SteeringPositionValue",
    "SymptomsHealthAspect",
    "SoldOut",
    "TransitMap",
    "GraphicNovel",
    "IndividualPhysician",
    "InviteAction",
    "CommentAction",
    "LowCalorieDiet",
    "RemixAlbum",
    "CassetteFormat",
    "ZoneBoardingPolicy",
    "AutomatedTeller",
    "DateTime",
    "VenueMap",
    "LikeAction",
    "MonetaryAmountDistribution",
    "Monday",
    "DirectDebit",
    "Lung",
    "Courthouse",
    "DesktopWebPlatform",
    "HardwareStore",
    "Time",
    "Neck",
    "ParcelService",
    "Hotel",
    "GeoCircle",
    "SizeSystemMetric",
    "DefenceEstablishment",
    "MixedEventAttendanceMode",
    "DJMixAlbum",
    "Female",
    "TierBenefitLoyaltyPoints",
    "RecommendedDoseSchedule",
    "InStock",
    "AskPublicNewsArticle",
    "DaySpa",
    "Pond",
    "Appearance",
    "MedicalSymptom",
    "Florist",
    "TierBenefitLoyaltyPrice",
    "AlbumRelease",
    "PrognosisHealthAspect",
    "MusicStore",
    "Obstetric",
    "HealthClub",
    "AutoRental",
    "MedicalScholarlyArticle",
    "SoundtrackAlbum",
    "HinduTemple",
    "CovidTestingFacility",
    "Canal",
    "SRP",
    "SpokenWordAlbum",
    "ByBankTransferInAdvance",
    "ComputerStore",
    "LockerDelivery",
    "MovieRentalStore",
    "TreatmentsHealthAspect",
    "JewelryStore",
    "Motel",
    "COD",
    "CafeOrCoffeeShop",
    "ReducedRelevanceForChildrenConsideration",
    "EmployerAggregateRating",
    "Distillery",
    "OutOfStock",
    "OfficeEquipmentStore",
    "BroadcastRelease",
    "Casino",
    "Male",
    "UsageOrScheduleHealthAspect",
    "TaxiVehicleUsage",
    "ActionStatusType",
    "HealthCare",
    "HowToTool",
    "CurrencyConversionService",
    "LivingWithHealthAspect",
    "VideoObjectSnapshot",
    "MerchantReturnFiniteReturnWindow",
    "BusinessSupport",
    "ListPrice",
    "Embassy",
    "ExerciseGym",
    "HealthcareConsideration",
    "OfflineEventAttendanceMode",
    "ReadPermission",
    "Physiotherapy",
    "MusculoskeletalExam",
    "Artery",
    "GroceryStore",
    "Church",
    "BikeStore",
    "PatientExperienceHealthAspect",
    "ClothingStore",
    "AnaerobicActivity",
    "OnlineEventAttendanceMode",
    "UnemploymentSupport",
    "LimitedAvailability",
    "EditedOrCroppedContent",
    "FMRadioChannel",
    "Installment",
    "ScheduleAction",
    "StrengthTraining",
    "AnalysisNewsArticle",
    "PrimaryCare",
    "StagedContent",
    "PetStore",
    "BenefitsHealthAspect",
    "BowlingAlley",
    "PostalAddress",
    "Saturday",
    "SkiResort",
    "ByInvoice",
    "Otolaryngologic",
    "MotorcycleDealer",
    "OriginalShippingFees",
    "ReturnLabelInBox",
    "ShoeStore",
    "Dermatology",
    "DepartmentStore",
    "Optometric",
    "APIReference",
    "ScreeningHealthAspect",
    "EmployeeRole",
    "HowToSupply",
    "Throat",
    "HearingImpairedSupported",
    "KosherDiet",
    "AssignAction",
    "AudiobookFormat",
    "HomeGoodsStore",
    "KeepProduct",
    "ItemListUnordered",
    "SizeSystemImperial",
    "FurnitureStore",
    "AutoWash",
    "DamagedCondition",
    "HowItWorksHealthAspect",
    "MadeToOrder",
    "RadioBroadcastService",
    "CompilationAlbum",
    "DislikeAction",
    "DemoAlbum",
    "HousePainter",
    "GolfCourse",
    "PostOffice",
    "Discontinued",
    "ComicSeries",
    "OutletStore",
    "LakeBodyOfWater",
    "BackgroundNewsArticle",
    "ElectronicsStore",
    "TattooParlor",
    "WeaponConsideration",
    "ReturnFeesCustomerResponsibility",
    "Hostel",
    "AgreeAction",
    "UsedCondition",
    "RsvpResponseNo",
    "Abdomen",
    "MinimumAdvertisedPrice",
    "BankOrCreditUnion",
    "CommunityHealth",
    "FullGameAvailability",
    "ComedyClub",
    "OpinionNewsArticle",
    "TierBenefitLoyaltyReturns",
    "ReportedDoseSchedule",
    "Balance",
    "PlasticSurgery",
    "Eye",
    "Date",
    "EBook",
    "RejectAction",
    "Mosque",
    "Oncologic",
    "BasicIncome",
    "EPRelease",
    "CertificationActive",
    "SeaBodyOfWater",
    "Attorney",
    "DefinitiveLegalValue",
    "GroupBoardingPolicy",
    "NightClub",
    "GettingAccessHealthAspect",
    "MultiPlayer",
    "Flexibility",
    "MovingCompany",
    "WholesaleStore",
    "ParentAudience",
    "OnSitePickup",
    "BeautySalon",
    "RsvpResponseYes",
    "PregnancyHealthAspect",
    "BuddhistTemple",
    "CancelAction",
    "Neuro",
    "ParkingMap",
    "Psychiatric",
    "OpenTrial",
    "PaymentDeclined",
    "EventRescheduled",
    "OrderProcessing",
    "AllWheelDriveConfiguration",
    "WearableMeasurementWidth",
    "MRI",
    "WearableMeasurementSleeve",
    "ReservationPending",
    "AlgorithmicallyEnhancedDigitalSource",
    "EUEnergyEfficiencyCategoryA1Plus",
    "WearableSizeSystemJP",
    "Radiography",
    "Nonprofit501c10",
    "RadiationTherapy",
    "WearableMeasurementCup",
    "WesternConventional",
    "PrescriptionOnly",
    "WearableSizeGroupPetite",
    "Nonprofit501c20",
    "InternationalTrial",
    "PercutaneousProcedure",
    "Nonprofit501c3",
    "EUEnergyEfficiencyCategoryA2Plus",
    "WearableSizeGroupBoys",
    "ReservationConfirmed",
    "WearableMeasurementBack",
    "TripleBlindedTrial",
    "OfflineTemporarily",
    "BodyMeasurementBust",
    "Renal",
    "WearableSizeGroupShort",
    "OrderInTransit",
    "FDAcategoryB",
    "WearableMeasurementInseam",
    "WearableSizeGroupMens",
    "WearableSizeGroupTall",
    "VideoGallery",
    "Hematologic",
    "Musculoskeletal",
    "CompositeSyntheticDigitalSource",
    "EvidenceLevelB",
    "ResultsAvailable",
    "PlaceboControlledTrial",
    "Neurologic",
    "WearableSizeSystemFR",
    "EUEnergyEfficiencyCategoryG",
    "CompositeCaptureDigitalSource",
    "Nonprofit501e",
    "Completed",
    "Longitudinal",
    "WearableMeasurementHips",
    "Dermatologic",
    "CharitableIncorporatedOrganization",
    "BodyMeasurementFoot",
    "WearableSizeGroupWomens",
    "Nonprofit501c21",
    "Withdrawn",
    "Infectious",
    "Nonprofit501c4",
    "NoninvasiveProcedure",
    "Nonprofit501c16",
    "Genetic",
    "OccupationalTherapy",
    "WearableSizeSystemDE",
    "EUEnergyEfficiencyCategoryE",
    "MortgageLoan",
    "MulticellularParasite",
    "OrderDelivered",
    "PET",
    "WearableSizeSystemEurope",
    "SingleCenterTrial",
    "Nonprofit501c7",
    "Nonprofit501c13",
    "TrainedAlgorithmicMediaDigitalSource",
    "Nonprofit501c5",
    "Anesthesia",
    "EnergyStarCertified",
    "EUEnergyEfficiencyCategoryA",
    "Diagnostic",
    "Float",
    "WearableMeasurementChestOrBust",
    "WearableSizeGroupHusky",
    "MedicalResearcher",
    "WearableMeasurementWaist",
    "Nonprofit501c24",
    "Nonprofit501c28",
    "Nonprofit501c15",
    "BodyMeasurementChest",
    "BodyMeasurementWeight",
    "XRay",
    "Chiropractic",
    "WearableSizeSystemCN",
    "BodyMeasurementInsideLeg",
    "MultiCenterTrial",
    "Nonprofit501n",
    "XPathType",
    "RandomizedTrial",
    "WearableSizeGroupExtraTall",
    "PrependAction",
    "WearableSizeSystemAU",
    "OfflinePermanently",
    "EvidenceLevelC",
    "PaymentPastDue",
    "EUEnergyEfficiencyCategoryC",
    "Rheumatologic",
    "CrossSectional",
    "Suspended",
    "WearableSizeSystemMX",
    "BodyMeasurementUnderbust",
    "Nonprofit501c2",
    "NotYetRecruiting",
    "WearableSizeGroupBig",
    "Nonprofit501c11",
    "Nonprofit501c6",
    "Nonprofit501c19",
    "Clinician",
    "WearableSizeGroupMisses",
    "Nonprofit527",
    "WearableMeasurementOutsideLeg",
    "RearWheelDriveConfiguration",
    "DataDrivenMediaDigitalSource",
    "PaymentComplete",
    "ResultsNotAvailable",
    "LiveBlogPosting",
    "ActiveNotRecruiting",
    "Nonprofit501c25",
    "EventScheduled",
    "WearableSizeSystemUK",
    "EnrollingByInvitation",
    "WearableSizeGroupInfants",
    "FrontWheelDriveConfiguration",
    "Nonprofit501f",
    "SingleBlindedTrial",
    "LaboratoryScience",
    "VirtualRecordingDigitalSource",
    "PronounceableText",
    "SpeechPathology",
    "PositiveFilmDigitalSource",
    "DigitalCaptureDigitalSource",
    "ReimbursementCap",
    "RightHandDriving",
    "WearableSizeSystemIT",
    "Integer",
    "CohortStudy",
    "BodyMeasurementNeck",
    "WearableSizeGroupExtraShort",
    "Nonprofit501c23",
    "Nonprofit501c9",
    "MinorHumanEditsDigitalSource",
    "CompositeWithTrainedAlgorithmicMediaDigitalSource",
    "WearableSizeSystemContinental",
    "Nonprofit501c17",
    "LimitedByGuaranteeCharity",
    "Nonprofit501c26",
    "Registry",
    "FourWheelDriveConfiguration",
    "EUEnergyEfficiencyCategoryA3Plus",
    "WearableMeasurementCollar",
    "CssSelectorType",
    "WearableSizeSystemBR",
    "ImageGallery",
    "WearableSizeGroupPlus",
    "FDAcategoryA",
    "Homeopathic",
    "ConfirmAction",
    "AppendAction",
    "BodyMeasurementHead",
    "DoubleBlindedTrial",
    "LeftHandDriving",
    "RespiratoryTherapy",
    "Pulmonary",
    "WearableMeasurementLength",
    "Observational",
    "WearableSizeGroupGirls",
    "OrderReturned",
    "PrintDigitalSource",
    "OrderPickupAvailable",
    "OrderProblem",
    "BodyMeasurementWaist",
    "WearableSizeSystemGS1",
    "Nonprofit501c22",
    "DigitalArtDigitalSource",
    "Fungus",
    "Cardiovascular",
    "Surgical",
    "BodyMeasurementHips",
    "OrderCancelled",
    "Nonprofit501k",
    "VitalSign",
    "ActiveActionStatus",
    "BrokerageAccount",
    "Pathology",
    "WearableSizeGroupMaternity",
    "ReservationHold",
    "EvidenceLevelA",
    "Nonprofit501q",
    "Dentistry",
    "Bacteria",
    "Online",
    "OnlineFull",
    "CatholicChurch",
    "CompletedActionStatus",
    "PaymentDue",
    "Urologic",
    "EUEnergyEfficiencyCategoryD",
    "PhysicalTherapy",
    "Virus",
    "Nonprofit501a",
    "Prion",
    "UKTrust",
    "FDAcategoryX",
    "Endocrine",
    "Wholesale",
    "FDAnotEvaluated",
    "Nonprofit501c8",
    "InForce",
    "WearableSizeSystemUS",
    "PaymentAutomaticallyApplied",
    "Therapeutic",
    "WearableSizeGroupJuniors",
    "Ultrasound",
    "InvestmentFund",
    "DepositAccount",
    "AlgorithmicMediaDigitalSource",
    "TraditionalChinese",
    "Nonprofit501c12",
    "Protozoa",
    "PotentialActionStatus",
    "WearableMeasurementHeight",
    "EventMovedOnline",
    "Nonprofit501c14",
    "True_",
    "False_",
    "OrderPaymentDue",
    "NonprofitANBI",
    "EventCancelled",
    "FailedActionStatus",
    "UnincorporatedAssociationCharity",
    "CaseSeries",
    "Nonprofit501c18",
    "Recruiting",
    "Nonprofit501d",
    "Nonprofit501c27",
    "Nonprofit501c1",
    "OTC",
    "EUEnergyEfficiencyCategoryB",
    "WearableSizeSystemEN13402",
    "Gastroenterologic",
    "Retail",
    "BodyMeasurementHand",
    "FDAcategoryD",
    "Toxicologic",
    "Osteopathic",
    "BodyMeasurementArm",
    "PartiallyInForce",
    "NotInForce",
    "WearableSizeGroupRegular",
    "RsvpAction",
    "BodyMeasurementHeight",
    "PharmacySpecialty",
    "EUEnergyEfficiencyCategoryF",
    "URL",
    "NegativeFilmDigitalSource",
    "FDAcategoryC",
    "CT",
    "Terminated",
    "NonprofitSBBI",
    "EventPostponed",
    "ReservationCancelled",
    "Ayurvedic",
]



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.EUEnergyEfficiencyEnumeration import (
    EUEnergyEfficiencyEnumeration,
)


class EUEnergyEfficiencyCategoryE(EUEnergyEfficiencyEnumeration):
    """Represents EU Energy Efficiency Class E as defined in EU energy labeling regulations.

    See: https://schema.org/EUEnergyEfficiencyCategoryE
    Model depth: 6
    """

    type_: str = Field(default="EUEnergyEfficiencyCategoryE", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Audience import Audience


class Researcher(Audience):
    """Researchers.

    See: https://schema.org/Researcher
    Model depth: 4
    """

    type_: str = Field(default="Researcher", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty


class Hematologic(MedicalSpecialty):
    """A specific branch of medical science that pertains to diagnosis and treatment of disorders of blood and blood
     producing organs.

    See: https://schema.org/Hematologic
    Model depth: 6
    """

    type_: str = Field(default="Hematologic", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.Game import Game
from pydantic2_schemaorg.SoftwareApplication import SoftwareApplication


class VideoGame(Game, SoftwareApplication):
    """A video game is an electronic game that involves human interaction with a user interface to generate visual
     feedback on a video device.

    See: https://schema.org/VideoGame
    Model depth: 4
    """

    type_: str = Field(default="VideoGame", alias="@type", const=True)
    trailer: Optional[Union[List[Union["VideoObject", str]], "VideoObject", str]] = (
        Field(
            default=None,
            description="The trailer of a movie or TV/radio series, season, episode, etc.",
        )
    )
    playMode: Optional[Union[List[Union["GamePlayMode", str]], "GamePlayMode", str]] = (
        Field(
            default=None,
            description="Indicates whether this game is multi-player, co-op or single-player. The game can be marked as multi-player, co-op and single-player at the same time.",
        )
    )
    gameEdition: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The edition of a video game.",
    )
    actors: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="An actor, e.g. in TV, radio, movie, video games etc. Actors can be associated with individual items or with a series, episode, clip.",
    )
    gameServer: Optional[Union[List[Union["GameServer", str]], "GameServer", str]] = (
        Field(
            default=None,
            description="The server on which it is possible to play the game.",
        )
    )
    director: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip.",
    )
    directors: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="A director of e.g. TV, radio, movie, video games etc. content. Directors can be associated with individual items or with a series, episode, clip.",
    )
    cheatCode: Optional[
        Union[List[Union["CreativeWork", str]], "CreativeWork", str]
    ] = Field(
        default=None,
        description="Cheat codes to the game.",
    )
    gameTip: Optional[Union[List[Union["CreativeWork", str]], "CreativeWork", str]] = (
        Field(
            default=None,
            description="Links to tips, tactics, etc.",
        )
    )
    gamePlatform: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "Thing"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "Thing",
        ]
    ] = Field(
        default=None,
        description='The electronic systems used to play <a href="http://en.wikipedia.org/wiki/Category:Video_game_platforms">video games</a>.',
    )
    actor: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="An actor, e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip.",
    )
    musicBy: Optional[
        Union[List[Union["Person", "MusicGroup", str]], "Person", "MusicGroup", str]
    ] = Field(
        default=None,
        description="The composer of the soundtrack.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.VideoObject import VideoObject
    from pydantic2_schemaorg.GamePlayMode import GamePlayMode
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.GameServer import GameServer
    from pydantic2_schemaorg.CreativeWork import CreativeWork
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Thing import Thing
    from pydantic2_schemaorg.MusicGroup import MusicGroup



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.ConsumeAction import ConsumeAction


class PlayGameAction(ConsumeAction):
    """The act of playing a video game.

    See: https://schema.org/PlayGameAction
    Model depth: 4
    """

    type_: str = Field(default="PlayGameAction", alias="@type", const=True)
    gameAvailabilityType: Optional[
        Union[
            List[Union[str, "Text", "GameAvailabilityEnumeration"]],
            str,
            "Text",
            "GameAvailabilityEnumeration",
        ]
    ] = Field(
        default=None,
        description="Indicates the availability type of the game content associated with this action, such as whether it is a full version or a demo.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.GameAvailabilityEnumeration import (
        GameAvailabilityEnumeration,
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DrugCostCategory import DrugCostCategory


class Retail(DrugCostCategory):
    """The drug's cost represents the retail cost of the drug.

    See: https://schema.org/Retail
    Model depth: 6
    """

    type_: str = Field(default="Retail", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.DefinedTermSet import DefinedTermSet


class CategoryCodeSet(DefinedTermSet):
    """A set of Category Code values.

    See: https://schema.org/CategoryCodeSet
    Model depth: 4
    """

    type_: str = Field(default="CategoryCodeSet", alias="@type", const=True)
    hasCategoryCode: Optional[
        Union[List[Union["CategoryCode", str]], "CategoryCode", str]
    ] = Field(
        default=None,
        description="A Category code contained in this code set.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.CategoryCode import CategoryCode



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class RsvpResponseType(Enumeration):
    """RsvpResponseType is an enumeration type whose instances represent responding to an RSVP request.

    See: https://schema.org/RsvpResponseType
    Model depth: 4
    """

    type_: str = Field(default="RsvpResponseType", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty
from pydantic2_schemaorg.MedicalBusiness import MedicalBusiness


class Physiotherapy(MedicalSpecialty, MedicalBusiness):
    """The practice of treatment of disease, injury, or deformity by physical methods such as massage, heat treatment,
     and exercise rather than by drugs or surgery.

    See: https://schema.org/Physiotherapy
    Model depth: 5
    """

    type_: str = Field(default="Physiotherapy", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.BodyMeasurementTypeEnumeration import (
    BodyMeasurementTypeEnumeration,
)


class BodyMeasurementInsideLeg(BodyMeasurementTypeEnumeration):
    """Inside leg (measured between crotch and soles of feet). Used, for example, to fit pants.

    See: https://schema.org/BodyMeasurementInsideLeg
    Model depth: 6
    """

    type_: str = Field(default="BodyMeasurementInsideLeg", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalIntangible import MedicalIntangible


class DrugStrength(MedicalIntangible):
    """A specific strength in which a medical drug is available in a specific country.

    See: https://schema.org/DrugStrength
    Model depth: 4
    """

    type_: str = Field(default="DrugStrength", alias="@type", const=True)
    strengthUnit: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The units of an active ingredient's strength, e.g. mg.",
    )
    maximumIntake: Optional[
        Union[List[Union["MaximumDoseSchedule", str]], "MaximumDoseSchedule", str]
    ] = Field(
        default=None,
        description="Recommended intake of this supplement for a given population as defined by a specific recommending authority.",
    )
    activeIngredient: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="An active ingredient, typically chemical compounds and/or biologic substances.",
    )
    strengthValue: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The value of an active ingredient's strength, e.g. 325.",
    )
    availableIn: Optional[
        Union[List[Union["AdministrativeArea", str]], "AdministrativeArea", str]
    ] = Field(
        default=None,
        description="The location in which the strength is available.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.MaximumDoseSchedule import MaximumDoseSchedule
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.AdministrativeArea import AdministrativeArea



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Comment import Comment


class CorrectionComment(Comment):
    """A [[comment]] that corrects [[CreativeWork]].

    See: https://schema.org/CorrectionComment
    Model depth: 4
    """

    type_: str = Field(default="CorrectionComment", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class VirtualLocation(Intangible):
    """An online or virtual location for attending events. For example, one may attend an online seminar or educational
     event. While a virtual location may be used as the location of an event, virtual locations should not be confused
     with physical locations in the real world.

    See: https://schema.org/VirtualLocation
    Model depth: 3
    """

    type_: str = Field(default="VirtualLocation", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MusicReleaseFormatType import MusicReleaseFormatType


class CassetteFormat(MusicReleaseFormatType):
    """CassetteFormat.

    See: https://schema.org/CassetteFormat
    Model depth: 5
    """

    type_: str = Field(default="CassetteFormat", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl, StrictBool, StrictInt, StrictFloat
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Residence import Residence


class ApartmentComplex(Residence):
    """Residence type: Apartment complex.

    See: https://schema.org/ApartmentComplex
    Model depth: 4
    """

    type_: str = Field(default="ApartmentComplex", alias="@type", const=True)
    numberOfBedrooms: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "QuantitativeValue", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The total integer number of bedrooms in a some [[Accommodation]], [[ApartmentComplex]] or [[FloorPlan]].",
    )
    petsAllowed: Optional[
        Union[
            List[Union[StrictBool, "Boolean", str, "Text"]],
            StrictBool,
            "Boolean",
            str,
            "Text",
        ]
    ] = Field(
        default=None,
        description="Indicates whether pets are allowed to enter the accommodation or lodging business. More detailed information can be put in a text value.",
    )
    numberOfAvailableAccommodationUnits: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="Indicates the number of available accommodation units in an [[ApartmentComplex]], or the number of accommodation units for a specific [[FloorPlan]] (within its specific [[ApartmentComplex]]). See also [[numberOfAccommodationUnits]].",
    )
    numberOfAccommodationUnits: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="Indicates the total (available plus unavailable) number of accommodation units in an [[ApartmentComplex]], or the number of accommodation units for a specific [[FloorPlan]] (within its specific [[ApartmentComplex]]). See also [[numberOfAvailableAccommodationUnits]].",
    )
    tourBookingPage: Optional[
        Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]
    ] = Field(
        default=None,
        description="A page providing information on how to book a tour of some [[Place]], such as an [[Accommodation]] or [[ApartmentComplex]] in a real estate setting, as well as other kinds of tours as appropriate.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.URL import URL



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DigitalPlatformEnumeration import DigitalPlatformEnumeration


class GenericWebPlatform(DigitalPlatformEnumeration):
    """Represents the generic notion of the Web Platform. More specific codes include [[MobileWebPlatform]] and
     [[DesktopWebPlatform]], as an incomplete list.

    See: https://schema.org/GenericWebPlatform
    Model depth: 5
    """

    type_: str = Field(default="GenericWebPlatform", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Room import Room


class HotelRoom(Room):
    """A hotel room is a single room in a hotel. <br /><br /> See also the <a href=\"/docs/hotels.html\">dedicated
     document on the use of schema.org for marking up hotels and other forms of accommodations</a>.

    See: https://schema.org/HotelRoom
    Model depth: 5
    """

    type_: str = Field(default="HotelRoom", alias="@type", const=True)
    occupancy: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The allowed total occupancy for the accommodation in persons (including infants etc). For individual accommodations, this is not necessarily the legal maximum but defines the permitted usage as per the contractual agreement (e.g. a double room used by a single person). Typical unit code(s): C62 for person.",
    )
    bed: Optional[
        Union[
            List[Union[str, "Text", "BedType", "BedDetails"]],
            str,
            "Text",
            "BedType",
            "BedDetails",
        ]
    ] = Field(
        default=None,
        description="The type of bed or beds included in the accommodation. For the single case of just one bed of a certain type, you use bed directly with a text. If you want to indicate the quantity of a certain kind of bed, use an instance of BedDetails. For more detailed information, use the amenityFeature property.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.BedType import BedType
    from pydantic2_schemaorg.BedDetails import BedDetails



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class NonprofitType(Enumeration):
    """NonprofitType enumerates several kinds of official non-profit types of which a non-profit organization
     can be.

    See: https://schema.org/NonprofitType
    Model depth: 4
    """

    type_: str = Field(default="NonprofitType", alias="@type", const=True)
